@ECHO OFF
REM #
REM # IBM Confidential 
REM #	
REM #   (c) Copyright IBM Corp. 2000, 2009 All Rights Reserved.
REM #
REM #   The source code for this program is not published or otherwise
REM #   divested of its trade secrets, irrespective of what has been 
REM #   deposited with the U.S. Copyright Office.

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::   
:: OVERVIEW:
::   
:: Note this exact same script is called for both
:: install and uninstall capabilities.  This file should typically not be called 
:: directly, use the install.bat and uninstall.bat instead.
::
:: USAGE  installInternal.bat <action> 
:: <action> ==
::				[ -INSTALL | -UNINSTALL] "<FunctionalTester parent dir>" <install-options>
::				  -QUERY 
::				  -UPDATE [ <update-options> ]  
:: <install-options> ==
::				 -ECLIPSE "<eclipse dir>" | -ECLIPSE_LAUNCHER "<eclipse exe location>"
::				[ -VSNET7.1 | -VSNET8 | -VSNET10] "<vs.net dir>"
::				  -JRE "<jre directory>" 
::
:: <update-options> ==
::				[ -VSNET7.1 | -VSNET8 | VSNET10] "<vs.net dir>"
::				  -NO_VSNET | -NO_VSNET7.1 | -NO_VSNET8 | -NO_VSNET10
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: DATE			COMMENT
:: 10-Jan-09	Adding Chages to include VS 2010 integration.
:: 18-Sep-09	Added registration command for VB Infiltrator components
:: 01-Apr-09 Fixed uninstall of RFT and the changes it makes to the SourceCode ControlProvider in the Registry.
::		 While uninstalling from Installation Manager ,it adds one more option "-UPDATE -NO_VSNET7.1" to the command line for UNINSTALL 
::		 apart from the already given options .
::		 This is a difference from -UNINSTALL that we give from commandline
:: 01-Jan-08    Proxy SDK-nl help integration with MSDN. Added and modified Call targets 
::              MSDN_NONENGLISH_PROXYSDK_USERGUIDE_INSTALL, MSDN_NONENGLISH_PROXYSDK and 
::              MSDNHelpUninstallUserGuide_NON_ENGLISH
::
:: 04-May-07    option -ECLIPSE_LAUNCHER introduced to support customers who use modified/renamed eclipse
::              which are customized
::
:: 13-Sep-06	Two new options introduced in -update option
::		-update -NO_VSNET8 uninstalls RFT integration with VS2005
::		-update -NO_VSNET7.1 uninstalls RFT integration with VS2003
::		-update -NO_VSNET uninstall either one of available VS2003 or 2005
:: 17-May-06	ClearCase support added
:: 5-Jun-06		Fixed query to work without any parameters other than -QUERY.
::				Query now checks both VS.NET IDEs.
::				We no longer create an eclipse links directory.
::				Installing vs7.1 deletes the rational_ft(w).exe.config files
::				if they were left in FunctionalTester\bin.
:: 21-Jun-06	Added FixupClearCase to registry var
::				Added -update, allowing incremental install or removal
:: 				of the vsnet support. Currently we only allow a single
::				IDE to be integrated.
::				If you specify just -update with no IDE argument, it checks
::				for .net framework additions, updates the gac, vb.net command lines,
::				and Siebel.
::				If you specify -update with one of the arguments to change the vsnet
::				IDE setting, it checks for additions of the .Net framework. -update does
::				not cover the scenario of uninstalling all .net frameworks. Use -uninstall
::				for that case.

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
SET DEBUG_OUTPUT=..true..
@echo ----------------------------------------------------------
@echo installInternal.bat %*
@echo ----------------------------------------------------------
@CALL :LogHeader Start

CALL :ProcessArgs %*
REM GOTO DO_NOTHING
IF %ERR_CODE% EQU ..success.. (
	@if %ARG_ACTION% EQU ..uninstall.. (
		@CALL :MainUninstall
	) ELSE (
		@if %ARG_ACTION% EQU ..update.. (
			@CALL :MainUpdateVsNet
		) ELSE (
			@CALL :Main
		)
	)
)
:DO_NOTHING
@CALL :LogHeader End
GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Process the command-line arguments
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ProcessArgs
SET THIS_BATCH_FILES_DIR=%~dp0
SET ARG_ACTION=..undefined..
SET ARG_PRODUCT_INSTALL="..undefined.."
SET ARG_ECLIPSE="..undefined.."
SET ARG_ECLIPSE_EXE="..undefined.."
SET ARG_VSNET71="..undefined.."
SET ARG_VSNET8="..undefined.."
SET ARG_VSNET10="..undefined.."
SET ARG_NO_VSNET="..undefined.."
SET ARG_NO_VSNET_VERSION="..undefined.."
SET ARG_JRE="..undefined.."
SET ARG_RAC="..undefined.."
SET UPDATE_NO_VSNET_CHANGE=..false..

	CALL :LogInfo THIS_BATCH_FILES_DIR is %THIS_BATCH_FILES_DIR%
	CALL :CheckFileExistance "%THIS_BATCH_FILES_DIR%rreg.exe"
	@IF  %ERR_CODE% EQU ..error.. (
		CALL :LogInfo File not found "%THIS_BATCH_FILES_DIR%rreg.exe"
		 GOTO :EOF
	)
	
CALL :setrreg "%THIS_BATCH_FILES_DIR%rreg.exe"

:nextProcessArgPair

	CALL :ProcessArgPair %1 %2

	IF %ERR_CODE% EQU ..error.. (
		REM # Had argument parsing error, we give up
		GOTO :EOF
	)
	IF %ERR_CODE% EQU ..moreArgs.. (
		Call :Debug ..moreArgs..
		shift
		shift
		GOTO :nextProcessArgPair
	)
	IF %ERR_CODE% EQU ..moreArgsShiftJustOne.. (
		Call :Debug .. moreArgsShiftJustOne..
		shift
		GOTO :nextProcessArgPair
	)
	REM # processed all args, now lets see if we have any invalid combinations

	IF "%~1" NEQ "" (
		REM # left-over arguments
		CALL :Error Unexpected arument: %1
		@GOTO :EOF
	)
	IF %ARG_ACTION% EQU ..undefined.. (
		CALL :Error Must specify -Install, -Uninstall, -Update or -Query
		@GOTO :EOF
	)

	REM # check the args if -update was specified
	IF %ARG_ACTION% EQU ..update.. (
		CALL :CheckUpdateArgs
	)
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)

	REM # for -query and -update we set the local args from the registry and environment
	IF %ARG_ACTION% EQU ..query.. (
		CALL :SetArgsFromEnvironmentAndRegistry
	)
	IF %ARG_ACTION% EQU ..update.. (
		CALL :SetArgsFromEnvironmentAndRegistry
	)
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)

	REM # check required args that must have been defined (or queried)
	IF %ARG_ECLIPSE% EQU "..undefined.." (
		CALL :Error Must specify Eclipse Directory
		@GOTO :EOF
	)

	IF %ARG_RAC% NEQ "..undefined.." (
		CALL :Error -RAC not yet implemented
		@GOTO :EOF
	)

	IF %ARG_ACTION% EQU ..query.. (
		GOTO :SKIP_JRE_CHECK
	)
	IF %ARG_JRE% EQU "..undefined.." (
		CALL :Error Must specify JRE
		@GOTO :EOF
	)

	CALL :ValidateArgJre
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
:SKIP_JRE_CHECK
	CALL :ValidateArgEclipse
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)

	CALL :SetGlobals
	@GOTO :EOF

:CheckUpdateArgs
	@SET ERR_CODE=..success..
	IF %ARG_VSNET71% NEQ "..undefined.." (
		GOTO :EOF
	)
	IF %ARG_VSNET8% NEQ "..undefined.." (
		GOTO :EOF
	)
	IF %ARG_VSNET10% NEQ "..undefined.." (
		GOTO :EOF
	)
	IF %ARG_NO_VSNET% NEQ "..undefined.." (
		GOTO :EOF
	)
	SET UPDATE_NO_VSNET_CHANGE=..true..
	GOTO :EOF

:SetArgsFromEnvironmentAndRegistry
	REM # ----------------- INSTALL DIR -----------------

	@CALL :QueryRftReg "Rational FT Install Directory"
	@ECHO IBM_RATIONAL_RFT_INSTALL_DIR from REGISTRY="%REG_VALUE%"
	@ECHO Environment Value for IBM_RATIONAL_RFT_INSTALL_DIR="%IBM_RATIONAL_RFT_INSTALL_DIR%"

	
		@CALL :QueryRftReg "Rational FT Install Directory"
		@ECHO IBM_RATIONAL_RFT_INSTALL_DIR from REGISTRY="%REG_VALUE%"

	@IF "%REG_VALUE%" == "" (
			@CALL :Error ??QUERY?? IBM_RATIONAL_RFT_INSTALL_DIR is not defined
			@GOTO :EOF
	) 
	
		@CALL :SetEnv IBM_RATIONAL_RFT_INSTALL_DIR "%REG_VALUE%"
		@ECHO  Environment variable IBM_RATIONAL_RFT_INSTALL_DIR after setting from Registry="%IBM_RATIONAL_RFT_INSTALL_DIR%"

		
	REM # IF ARG_PRODUCT_INSTALL is not defined but the env var is, get that value
	IF %ARG_PRODUCT_INSTALL% EQU "..undefined.." (
		Call :FixFileNameSlashes "%IBM_RATIONAL_RFT_INSTALL_DIR%\..\.."
	)
	
	IF %ARG_PRODUCT_INSTALL% EQU "..undefined.." (
		@ECHO  Environment variable IBM_RATIONAL_RFT_INSTALL_DIR="%IBM_RATIONAL_RFT_INSTALL_DIR%"
		SET ARG_PRODUCT_INSTALL="%FILE_VALUE%"
	)


	REM # ----------------- ECLIPSE DIR -----------------
	@ECHO  Environment Value for IBM_RATIONAL_RFT_ECLIPSE_DIR=%IBM_RATIONAL_RFT_ECLIPSE_DIR%
	
	@CALL :QueryRftReg "Eclipse Directory"
	@ECHO IBM_RATIONAL_RFT_ECLIPSE_DIR from REGISTRY="%REG_VALUE%"

		@CALL :QueryRftReg "Eclipse Directory"
		@ECHO IBM_RATIONAL_RFT_ECLIPSE_DIR from REGISTRY="%REG_VALUE%"
               
	@IF "%REG_VALUE%" == "" (
		@CALL :Error ??QUERY?? IBM_RATIONAL_RFT_ECLIPSE_DIR is not defined
		@GOTO :EOF
	)
	@CALL :SetEnv IBM_RATIONAL_RFT_ECLIPSE_DIR "%REG_VALUE%"
	@ECHO  Environment variable IBM_RATIONAL_RFT_ECLIPSE_DIR after setting from Registry=%IBM_RATIONAL_RFT_INSTALL_DIR%
	

	REM # IF ARG_ECLIPSE is not defined but the env var is, get that value
	IF %ARG_ECLIPSE% EQU "..undefined.." (
		Call :FixFileNameSlashes "%IBM_RATIONAL_RFT_ECLIPSE_DIR%"
	)
	IF %ARG_ECLIPSE% EQU "..undefined.." (
		@ECHO  Environment variable IBM_RATIONAL_RFT_ECLIPSE_DIR="%IBM_RATIONAL_RFT_ECLIPSE_DIR%"
		SET ARG_ECLIPSE="%FILE_VALUE%"
	)

	
	REM # ----------------- ECLIPSE EXE ------------------
	IF %ARG_ECLIPSE_EXE% EQU "..undefined.." (
		CALL :QueryRftReg "Rational FT Java IDE"
	)
	IF %ARG_ECLIPSE_EXE% EQU "..undefined.." (
		IF "%REG_VALUE%" EQU "" (
			IF %ARG_ACTION% EQU ..query.. (
				ECHO ??QUERY?? Rational FT Java IDE not defined in registry
				GOTO :EOF
			)
			CALL :Error Rational FT Java IDE not defined in registry
		) ELSE (
			@ECHO Registry Variable Rational FT Java IDE="%REG_VALUE%"
			@SET ARG_ECLIPSE_EXE="%REG_VALUE%"
		)
	)		


	

	REM # ----------------- JRE ------------------
	IF %ARG_JRE% EQU "..undefined.." (
		CALL :QueryRftReg "Rational FT JRE"
	)
	IF %ARG_JRE% EQU "..undefined.." (
		IF "%REG_VALUE%" EQU "" (
			IF %ARG_ACTION% EQU ..query.. (
				ECHO ??QUERY?? Rational FT JRE not defined in registry
				GOTO :EOF
			)
			CALL :Error Rational FT JRE not defined in registry
		) ELSE (
			@ECHO Registry Variable Rational FT JRE="%REG_VALUE%"
			@SET ARG_JRE="%REG_VALUE%"
		)
	)

	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Process a command-line argument pair
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ProcessArgPair
	CALL :Debug ProcessArgPair %1 %2
	SET ERR_CODE=..success..
	IF "x%~1" EQU "x" (
		GOTO :EOF
	)
	SET ERR_CODE=..moreArgs..
	IF /I "%1" EQU "-INSTALL" (
		CALL :ProcessArgPairInstall %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-UNINSTALL" (
		CALL :ProcessArgPairUnInstall %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-QUERY" (
		CALL :ProcessArgPairQuery %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-UPDATE" (
		CALL :ProcessArgPairUpdate %1 %2
		GOTO :EOF
	)

	IF %ARG_ACTION% EQU ..undefined.. (
		CALL :Error First argument must be one of: -Install, -Uninstall, -Update or -Query
		@GOTO :EOF
	)
	
	IF /I "%~1" EQU "-ECLIPSE" (
		CALL :ProcessArgPairEclipse %1 %2
		CALL :SetArg "%1" "%~2\eclipse.exe" ARG_ECLIPSE_EXE
		GOTO :EOF
	)

	IF /I "%~1" EQU "-ECLIPSE_LAUNCHER" (
		CALL :TRIMANDPROCESS "%~dp2" 
		REM CALL :SetArg "%1" "%~2" ARG_ECLIPSE_EXE
		CALL :SetArg %1 %2 ARG_ECLIPSE_EXE
		GOTO :EOF
	)
	

	IF /I "%~1" EQU "-VSNET7.1" (
		CALL :ProcessArgPairVSNet71 %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-VSNET8" (
		CALL :ProcessArgPairVSNet8 %1 %2
		GOTO :EOF
	)
	IF /I "%~1" EQU "-VSNET10" (
		CALL :ProcessArgPairVSNet10 %1 %2
		GOTO :EOF
	)	

	IF /I "%~1" EQU "-NO_VSNET" (
		CALL :ProcessArgPairNoVSNet %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-NO_VSNET7.1" (
		CALL :ProcessArgPairNoVSNet7.1 %1 %2
		GOTO :EOF
	)


	IF /I "%~1" EQU "-NO_VSNET8" (
		CALL :ProcessArgPairNoVSNet8 %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-NO_VSNET10" (
		CALL :ProcessArgPairNoVSNet10 %1 %2
		GOTO :EOF
	)


	IF /I "%~1" EQU "-JRE" (
		CALL :ProcessArgPairJRE %1 %2
		GOTO :EOF
	)

	IF /I "%~1" EQU "-RAC" (
		CALL :ProcessArgPairRAC %1 %2
		GOTO :EOF
	)

	GOTO :EOF


:ProcessArgPairInstall
	IF  %ARG_ACTION% NEQ ..undefined.. (
		CALL :Error Invalid arguments, specified action [Install/Uninstall/Query/Update] twice
		GOTO :EOF
	)
	SET ARG_ACTION=..install..
	CALL :SetArg %1 "%~2" ARG_PRODUCT_INSTALL
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance "%ARG_PRODUCT_INSTALL%"
	GOTO :EOF	

:ProcessArgPairUnInstall
	IF  %ARG_ACTION% NEQ ..undefined.. (
		CALL :Error Invalid arguments, specified action [Install/Uninstall/Query/Update] twice
		GOTO :EOF
	)
	SET ARG_ACTION=..uninstall..
	CALL :SetArg %1 "%~2" ARG_PRODUCT_INSTALL
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance "%ARG_PRODUCT_INSTALL%"
	GOTO :EOF

:ProcessArgPairQuery
	SET ERR_CODE=..moreArgsShiftJustOne..
	IF  %ARG_ACTION% NEQ ..undefined.. (
		CALL :Error Invalid arguments, specified action [Install/Uninstall/Query/Update] twice
		GOTO :EOF
	)
	SET ARG_ACTION=..query..
	GOTO :EOF

:ProcessArgPairUpdate
	SET ERR_CODE=..moreArgsShiftJustOne..
	IF  %ARG_ACTION% NEQ ..undefined.. (
		CALL :Error Invalid arguments, specified action [Install/Uninstall/Query/Update] twice
		GOTO :EOF
	)
	SET ARG_ACTION=..update..
	GOTO :EOF

:TRIMANDPROCESS 
	SET STRINGRET=%~1
	IF "%STRINGRET:~-1%"=="\" SET STRINGRET=%STRINGRET:~0,-1%
    	ECHO Value of Eclipse Folder After Trimming : %STRINGRET%
	CALL :ProcessArgPairEclipse %1 "%STRINGRET%"
	GOTO :EOF

:ProcessArgPairEclipse
	IF  %ARG_ECLIPSE% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified -ECLIPSE twice
		GOTO :EOF
	)
	CALL :SetArg %1 "%~2" ARG_ECLIPSE
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance "%ARG_ECLIPSE%"
	GOTO :EOF

:ProcessArgPairVSNet71
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified -VSNET7.1 twice
		GOTO :EOF
	)
	IF  %ARG_VSNET8% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -VSNET8. Only one Visual Studio IDE can be used.
		GOTO :EOF
	)
	IF  %ARG_VSNET10% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -VSNET10. Only one Visual Studio IDE can be used.
		GOTO :EOF
	)
	
	CALL :SetArg %1 "%~2" ARG_VSNET71
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance %ARG_VSNET71%
	GOTO :EOF

:ProcessArgPairVSNet8
	IF  %ARG_VSNET8% NEQ "..undefined.." (
 		CALL :Error Invalid arguments, specified -VSNET8 twice
		GOTO :EOF
	)
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -VSNET8. Only one Visual Studio IDE can be used.
		GOTO :EOF
	)
	IF  %ARG_VSNET10% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET8 and -VSNET10. Only one Visual Studio IDE can be used.
		GOTO :EOF
	)
	CALL :SetArg %1 "%~2" ARG_VSNET8
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance %ARG_VSNET8%
	GOTO :EOF
:ProcessArgPairVSNet10
	IF  %ARG_VSNET10% NEQ "..undefined.." (
 		CALL :Error Invalid arguments, specified -VSNET10 twice
		GOTO :EOF
	)
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -VSNET10. Only one Visual Studio IDE can be used.
		GOTO :EOF
	)
	IF  %ARG_VSNET8% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET8 and -VSNET10. Only one Visual Studio IDE can be used.
		GOTO :EOF
	)
	CALL :SetArg %1 "%~2" ARG_VSNET10
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance %ARG_VSNET10%
	GOTO :EOF

:ProcessArgPairNoVSNet
	SET ERR_CODE=..moreArgsShiftJustOne..
	IF  %ARG_VSNET8% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET8 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET10% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET10 and -NO_VSNET. 
		GOTO :EOF
	)
	CALL :SetArg %1 ..true.. ARG_NO_VSNET
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	GOTO :EOF

:ProcessArgPairNoVSNet7.1
	SET ERR_CODE=..moreArgsShiftJustOne..
	IF  %ARG_VSNET8% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET8 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET10% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET10 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -NO_VSNET. 
		GOTO :EOF
	)
	SET ARG_NO_VSNET_VERSION="..VS7.1.."
	CALL :SetArg %1 ..true.. ARG_NO_VSNET
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	GOTO :EOF

:ProcessArgPairNoVSNet8
	SET ERR_CODE=..moreArgsShiftJustOne..
	IF  %ARG_VSNET8% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET8 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET10% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET10 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -NO_VSNET. 
		GOTO :EOF
	)
	SET ARG_NO_VSNET_VERSION="..vs8.."
	CALL :SetArg %1 ..true.. ARG_NO_VSNET
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	GOTO :EOF

:ProcessArgPairNoVSNet10
	SET ERR_CODE=..moreArgsShiftJustOne..
	IF  %ARG_VSNET8% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET8 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET10% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET10 and -NO_VSNET. 
		GOTO :EOF
	)
	IF  %ARG_VSNET71% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified both -VSNET7.1 and -NO_VSNET. 
		GOTO :EOF
	)
	SET ARG_NO_VSNET_VERSION="..vs10.."
	CALL :SetArg %1 ..true.. ARG_NO_VSNET
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	GOTO :EOF


:ProcessArgPairJRE
	IF  %ARG_JRE% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified -JRE twice
		GOTO :EOF
	)
	CALL :SetArg %1 "%~2" ARG_JRE
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	GOTO :EOF

:ProcessArgPairRAC
	IF  %ARG_RAC% NEQ "..undefined.." (
		CALL :Error Invalid arguments, specified -RAC twice
		GOTO :EOF
	)
	CALL :SetArg %1 "%~2" ARG_RAC
	IF %ERR_CODE% NEQ ..success.. (
		GOTO :EOF
	)
	CALL :CheckFileExistance %ARG_RAC%
	GOTO :EOF

:Concat
	CALL :DEBUG SET %3="%~1%~2"
	SET %3="%~1%~2"
	GOTO :EOF

:SetArg
	IF "%~2"=="" (
		CALL :Error Missing value for argument %1
		GOTO :EOF
	)
	CALL :Debug SET %3="%~2"
	SET %3="%~2"

	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Initialize global setting used throughout this install/uninstall 
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetGlobals
	CALL :Debug SetGlobals
	SET CUST_DIR=..undefined..

	SET IDE_VSNET_DIR="..undefined.."
	IF %ARG_VSNET8% NEQ "..undefined.." (
		SET IDE_VSNET_DIR=%ARG_VSNET8%
	)
	IF %ARG_VSNET71% NEQ "..undefined.." (
		SET IDE_VSNET_DIR=%ARG_VSNET71%
	)
	IF %ARG_VSNET10% NEQ "..undefined.." (
		SET IDE_VSNET_DIR=%ARG_VSNET10%
	)
	
	SET NET_FRAMEWORK_FOUND=..undefined..

	CALL :Concat %ARG_PRODUCT_INSTALL% "\FunctionalTester\bin" FT_BIN_DIR
REM	SET FT_BIN_DIR=%ARG_PRODUCT_INSTALL%\FunctionalTester\bin
REM	SET FT_InstallScripts_DIR=%ARG_PRODUCT_INSTALL%\FunctionalTester\installscripts
	CALL :Concat %ARG_PRODUCT_INSTALL% "\FunctionalTester\installscripts" FT_InstallScripts_DIR
REM	CALL :Debug SET FT_InstallScripts_DIR=%ARG_PRODUCT_INSTALL%\FunctionalTester\installscripts

	CALL :Concat %ARG_PRODUCT_INSTALL% "\FunctionalTester\vsnet" FT_VSNET_DIR
REM	SET FT_VSNET_DIR=%ARG_PRODUCT_INSTALL%\FunctionalTester\vsnet
	IF %ARG_VSNET8% NEQ "..undefined.." (
REM		SET FT_msdnhelp_DIR=%FT_VSNET_DIR%\MSDNHelp\VS2005 
	CALL :Concat %FT_VSNET_DIR% "\MSDNHelp\VS2005" FT_msdnhelp_DIR
	)
	IF %ARG_VSNET71% NEQ "..undefined.." (
REM		SET FT_msdnhelp_DIR=%FT_VSNET_DIR%\MSDNHelp\VS2003
		CALL :Concat %FT_VSNET_DIR% "\MSDNHelp\VS2005" FT_msdnhelp_DIR
	)
	@SET ADDHELP=%FT_InstallScripts_DIR%\AddHelpCollection.exe
	@SET GACUTILITY=%FT_InstallScripts_DIR%\gacutility.exe

	SET ERR_CODE=..success..

	@GOTO :EOF

:setrreg
	SET RREG=%~s1
	CALL :Debug Set RREG=%rreg%
	
	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Main (install and query)
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:Main
	REM # Note that CheckForDotNetFramework sets REGASM if it finds a .net framework.
	CALL :CheckForDotNetFramework
	CALL :CoreInstall
	REM # Temporary install of links into eclipse, this normally does not install into eclipse at all
	CALL :EclipseInstall

	REM # ----------------- AssociateFileTypes ------------------	
	CALL :AssociateFileTypes

	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :IvoryPluginProperties	
	
	SET ERR_CODE=..success..
	IF %NET_FRAMEWORK_FOUND% EQU ..true.. (
		@ECHO =================== GAC rtxftnet ===================
		CALL :GacUtilityRtxFtNet %FT_BIN_DIR% rtxftnet.dll policy.7.0.rtxftnet.dll
	)
	@if %ERR_CODE% NEQ ..success.. @GOTO :EOF

	CALL :ClearCaseInstall
	
	@IF %ARG_ACTION% EQU ..install.. (
		CALL :VSNetInstall		
		CALL :ConfigFT_EXE_FOR_NETFramework
	) ELSE (
		CALL :QueryNetIde 7.1
		CALL :QueryNetIde 8.0
		CALL :QueryNetIde 10.0
	)
	
	
	
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	REM # Do we still need to clean up the rtclearcaseif.dll getting errantly regasm'd???
	REM # CALL :CleanupRtClearCaseIfDLL

	IF %NET_FRAMEWORK_FOUND% EQU ..true.. (
		CALL :Siebel
		CALL :SAP

	) ELSE (
		ECHO *** No .Net Framework found so SAP and Siebel support cannot be installed
	)

	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Main (uninstall)
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:MainUninstall

	REM # Note that CheckForDotNetFramework sets REGASM if it finds a .net framework.
	CALL :CheckForDotNetFramework

	IF %NET_FRAMEWORK_FOUND% EQU ..true.. (
		CALL :Siebel
		CALL :SAP

	) ELSE (
		ECHO *** No .Net Framework found so SAP and Siebel support cannot be uninstalled
	)
        
	CALL :ClearCaseInstall
        
	CALL :VSNetInstall
	CALL :ConfigFT_EXE_FOR_NETFramework
	
	CALL :UnenableAll
	CALL :IvoryPluginProperties	

	SET ERR_CODE=..success..
	IF %NET_FRAMEWORK_FOUND% EQU ..true.. (
		@ECHO =================== GAC rtxftnet ===================
		CALL :GacUtilityRtxFtNet %FT_BIN_DIR% rtxftnet.dll policy.7.0.rtxftnet.dll
	)

	REM # Temporary install of links into eclipse, this normally does not install into eclipse at all
	CALL :EclipseInstall

	CALL :CoreInstall

	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Main (update)
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:MainUpdateVsNet
	REM # Note that CheckForDotNetFramework sets REGASM if it finds a .net framework.
	CALL :CheckForDotNetFramework

	IF %NET_FRAMEWORK_FOUND% EQU ..false.. (
		CALL :ERROR Can't update Visual Studio IDE as .Net Framework was not found
		GOTO :EOF
	)

	REM # Check to see if we did not know about .net framework before!
	CALL :UpdateNetFramework

	REM # We want to update the command line tools whether we do the IDE or not
	SETLOCAL
		SET ARG_ACTION=..install..
		CALL :ConfigFT_EXE_FOR_NETFramework
	ENDLOCAL

	IF %UPDATE_NO_VSNET_CHANGE% EQU ..true.. (
		CALL :Debug No change to vsnet
		GOTO :EOF
	)
	IF %ARG_NO_VSNET_VERSION% EQU "..undefined.." (
     	
		CALL :GetNetIdeLocation 7.1
		IF "%REG_VALUE%" NEQ "" (
			CALL :UpdateUninstallNetIde 7.1
		)
		CALL :GetNetIdeLocation 8.0
		IF "%REG_VALUE%" NEQ "" (
			CALL :UpdateUninstallNetIde 8
		)
		CALL :GetNetIdeLocation 10.0
		IF "%REG_VALUE%" NEQ "" (
			CALL :UpdateUninstallNetIde 10
		)
	)
	
	IF %ARG_NO_VSNET_VERSION% EQU "..VS7.1.." (
		CALL :GetNetIdeLocation 7.1
		IF "REG_VALUE" NEQ "" (
			CALL :UpdateUninstallNetIde 7.1
		)
	)
     
	
	IF %ARG_NO_VSNET_VERSION% EQU "..vs8.." (
		echo I am going to caLL GETNETIDE	
		CALL :GetNetIdeLocation 8.0
		ECHO THE REG VALUE IS "%REG_VALUE%"
		IF "%REG_VALUE%" NEQ "" (
		
		CALL :UpdateUninstallNetIde 8
 
		)
	)
	
	IF %ARG_NO_VSNET_VERSION% EQU "..vs10.." (
		echo I am going to caLL GETNETIDE	
		CALL :GetNetIdeLocation 10.0
		ECHO THE REG VALUE IS "%REG_VALUE%"
		IF "%REG_VALUE%" NEQ "" (
		
		CALL :UpdateUninstallNetIde 10
 
		)
	)
	

	
	@IF %ARG_NO_VSNET% EQU "..undefined.." (
		CALL :UpdateVSNetInstall
	)
	@GOTO :EOF

:UpdateUninstallNetIde
	@ECHO === UpdateUninstallNetIde %1
	SETLOCAL
	SET ARG_ACTION=..uninstall..
	SET IDE_VSNET_DIR="%REG_VALUE%"

	IF %1 EQU 7.1 (
		SET ARG_VSNET71="%REG_VALUE%"
		SET ARG_VSNET8="..undefined.."
		SET ARG_VSNET10="..undefined.."
	)
	IF %1 EQU 8 (
		SET ARG_VSNET71="..undefined.."
		SET ARG_VSNET8="%REG_VALUE%"
		SET ARG_VSNET10="..undefined.."
	)
	IF %1 EQU 10 (
		SET ARG_VSNET71="..undefined.."
		SET ARG_VSNET8="..undefined.."
		SET ARG_VSNET10="%REG_VALUE%"
	)	

	
	
	CALL :VsNetInstall
	REM # CALL :ConfigFT_EXE_FOR_NETFramework
	ENDLOCAL
	GOTO :EOF

:UpdateVSNetInstall
	SETLOCAL
	SET ARG_ACTION=..install..
	CALL :VsNetInstall
	ENDLOCAL
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:LogHeader
	@echo --------------------------------- RFT ----------------------------------
	@Date /T
	@Time /T
	@echo "Current Directory:"
	cd
	@echo -------------------------------------------------------------------------
	@GOTO	:EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Set System Environment settings
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CoreInstall
	@ECHO =================== CoreInstall ===================
	CALL :DefineEnv IBM_RATIONAL_RFT_INSTALL_DIR %FT_BIN_DIR%
	CALL :DefineEnv IBM_RATIONAL_RFT_ECLIPSE_DIR %ARG_ECLIPSE%
	%RREG% envSettingChange

	CALL :DefineRftReg "Rational FT Install Directory" %FT_BIN_DIR%
	CALL :DefineRftReg "Eclipse Directory" %ARG_ECLIPSE%
	CALL :SetJRE

	 
	CALL :DefineRftReg "Rational FT Samples" %ARG_PRODUCT_INSTALL%\FunctionalTester\FTSamples

	CALL :SetNetAssembly
	
	CALL :CreateCustConfigDirs

	CALL :CallRegsrv %FT_BIN_DIR%\RFTFlexPlugin.dll
	CALL :CallRegsrv %FT_BIN_DIR%\RFTFlexPluginPS.dll
	
	CALL :CallRegsrv %FT_BIN_DIR%\VB5Infiltrator.dll
	CALL :CallRegsrv %FT_BIN_DIR%\VB6Dynenabler.dll
	
	CALL :CallRegsrv %FT_BIN_DIR%\solman.dll

	@GOTO :EOF

:SetNetAssembly
	IF %NET_FRAMEWORK_FOUND% EQU ..false.. (
		GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..install.. (
		%FT_BIN_DIR%\rtivregister.exe
		@IF %ERRORLEVEL% == 0 ( 
			@ECHO rtivregister succeeded
		) else (
			@CALL :ERROR rtivregister failed
		)
		@GOTO :EOF
	) 
	@if %ARG_ACTION% EQU ..uninstall.. (
		%FT_BIN_DIR%\rtivregister.exe -remove
		@IF %ERRORLEVEL% == 0 ( 
			@ECHO rtivregister succeeded
		) else (
			@CALL :ErrorNoStop rtivregister failed
		)
		@GOTO :EOF
	)
	if %ARG_ACTION% EQU ..query.. (
		CALL :ParseRtxFtNetPolicyConfigForVersion
	)
	if %ARG_ACTION% EQU ..query.. (
		IF "%rtxFtNetVersion%" EQU "" (
			ECHO ??QUERY?? We do not have a policy file
		)
		CALL :QueryRftReg "Rational FT Net Assembly Name"
		CALL :QueryRftReg "Rational FT Net Framework Versions"
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF
	
:SetJRE
	IF %ARG_JRE% EQU "..undefined.." (
		@CALL :Error SetJRE called with ARG_JRE undefined
		GOTO :EOF
	)
	CALL :DefineRftReg "Rational FT JRE" %ARG_JRE%
	CALL :DefineRftReg "Rational FT Playback JRE" %ARG_JRE%
	@GOTO :EOF

:DefineEnv
	@if %ARG_ACTION% EQU ..install.. (
		@CALL :SetEnv %1 %2
		@GOTO :EOF
	) 
	@if %ARG_ACTION% EQU ..uninstall.. (
		@CALL :UnSetEnv %1
		@GOTO :EOF
	)
	if %ARG_ACTION% EQU ..query.. (
		CALL :QueryEnv %1
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

:DefineRftReg
	@if %ARG_ACTION% EQU ..install.. (
		CALL :SetRftReg %1 %2
		@GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..uninstall.. (
		CALL :UnSetRftReg %1
		@GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..query.. (
		CALL :queryRftReg %1
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

:DefineReg
	@if %ARG_ACTION% EQU ..install.. (
		CALL :SetReg %1 %2 %3
		@GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..uninstall.. (
		CALL :UnSetReg %1 %2
		@GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..query.. (
		CALL :queryReg %1 %2
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Unenable all
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UnenableAll
	@ECHO Checking for customization file, the file may be copied to recover from possible corruption
	CALL :CreateCustConfigDirsInstall
	PUSHD %ARG_JRE%
	@ECHO Unenable %ARG_JRE%
	%FT_InstallScripts_DIR%\unenable_jre.exe
	%ARG_JRE%\bin\java.exe -jar "%IBM_RATIONAL_RFT_INSTALL_DIR%\rational_ft.jar" -disableall
	POPD 
	@GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Register RFT ClearCase support
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ClearCaseInstall
	@ECHO =================== ClearCaseInstall ===================
	REM # These registry variables are in the normal RFT registry collection, and
	REM # can be set even if CC is not installed.
	@CALL :DefineRftReg "SCCServerName" "Functional Test ClearCase"
	@CALL :DefineRftReg "SCCServerPath" %FT_BIN_DIR%\rftsccif.dll
	@CALL :DefineRftReg "FixupClearCase" 1

	REM # Check the current provider
	@CALL :GetReg "HKLM\SOFTWARE\SourceCodeControlProvider" ProviderRegKey
	@if %ARG_ACTION% EQU ..uninstall.. (
	@CALL :GetPreviousProviderRegkey "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey
		CALL :ClearCaseUnInstallProvider
	)
	@if %ARG_ACTION% EQU ..install.. (
		CALL :ClearCaseInstallProvider 
	)
	@if %ARG_ACTION% EQU ..query.. (
		CALL :ClearCaseQueryProvider 
	)
	
	REM # Register Type Managers
	@CALL :RegisterCCTypeManager _rftdef
	@CALL :RegisterCCTypeManager _rftmap
	@CALL :RegisterCCTypeManager _rftvp
	@GOTO :EOF

:ClearCaseQueryProvider
	@ECHO ??QUERY?? HKLM\SOFTWARE\SourceCodeControlProvider\ProviderRegKey = "%REG_VALUE%"
	@CALL :GetReg "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey 
	@ECHO ??QUERY?? HKLM\SOFTWARE\SourceCodeControlProvider\PreviousProviderRegKey = "%REG_VALUE%"
	@CALL :GetReg "HKLM\SOFTWARE\SourceCodeControlProvider\InstalledSCCProviders" "Functional Test ClearCase" 
	@ECHO ??QUERY?? "HKLM\SOFTWARE\SourceCodeControlProvider\InstalledSCCProviders\Functional Test ClearCase" = "%REG_VALUE%"
	@GOTO :EOF
	
:ClearCaseInstallProvider
REM # @IF %IDE_VSNET_DIR% EQU "..undefined.." (
REM # 	REM # Not interating with Vs.Net, so no SCC is needed
REM # 	@GOTO :EOF
REM # )
	
	
REM # Ideally user should insatll CC and then RFT . However , user may install clearcase after installing RFT. So to make 
REM # sure RFT-CC integration works we are removing check for cleacase installation and adding entires corresponding to  
REM # clearcase assuming that CC enttires awould always be at  ""HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers"
REM # This would make atleast Java side working. For Visuastudio few more keys are required for which we are adding them 
REM # internally through API in project init operation.

REM #	 @IF "%REG_VALUE%" NEQ "Software\Atria\ClearCase" (
REM #		@ECHO Cannot register the RFT SCC provider as the current provider is not ClearCase:
REM #		@ECHO - HKLM\SOFTWARE\SourceCodeControlProvider\ProviderRegKey = "%REG_VALUE%"
REM #		@GOTO :EOF
REM #	)
	
	REM # It is CC, so we filter it 

REM #	@CALL :DefineReg "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey "Software\Atria\ClearCase"
	@CALL :DefineReg "HKLM\SOFTWARE\SourceCodeControlProvider" ProviderRegKey "Software\Rational Software\Rational Test\8"
	@CALL :DefineReg "HKLM\SOFTWARE\SourceCodeControlProvider\InstalledSCCProviders" "Functional Test ClearCase" "Software\Rational Software\Rational Test\8"
	if "%REG_VALUE%" EQU "Software\Atria\ClearCase" (
	@CALL :SetDwordReg "HKCU\SOFTWARE\Atria\ClearCase\CurrentVersion" CCVSOverRide 1 
	)
	if "%REG_VALUE%" EQU "" (
	@CALL :DefineReg "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey "Software\Atria\ClearCase"
	@GOTO :EOF
	) 
	if "%REG_VALUE%" EQU "Software\Rational Software\Rational Test\8" (
REM # @ECHO Provider key is RFT so we don't put its value in Previous Provider Key
	) ELSE (
	@CALL :DefineReg "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey "%REG_VALUE%"
	)
	@GOTO :EOF

:ClearCaseUnInstallProvider
REM #	@IF %IDE_VSNET_DIR% EQU "..undefined.." (
REM #		REM # Don't unregister the RFT SCC support as we are not removing VS.Net integration
REM #			@GOTO :EOF
REM #		)
	
	@IF "%REG_VALUE%" NEQ "Software\Rational Software\Rational Test\8" (
		@ECHO Cannot unregister the RFT SCC provider as the current provider is not RFT:
		@ECHO - HKLM\SOFTWARE\SourceCodeControlProvider\ProviderRegKey = "%REG_VALUE%"
		@GOTO :EOF
	)
REM #
REM # @CALL :UnSetReg "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey 
REM #	@CALL :SetReg "HKLM\SOFTWARE\SourceCodeControlProvider" ProviderRegKey "Software\Atria\ClearCase"
REM #	@CALL :UnSetReg "HKLM\SOFTWARE\SourceCodeControlProvider\InstalledSCCProviders" "Functional Test ClearCase"
REM #	@GOTO :EOF
	if "%REG_VALUE%" EQU "Software\Rational Software\Rational Test\8" (
		@IF "%REG_VALUENEW%" EQU "Software\Rational Software\Rational Test\8" (
	 	@CALL :SetReg "HKLM\SOFTWARE\SourceCodeControlProvider" ProviderRegKey "Software\Atria\ClearCase"
		) ELSE (
		@CALL :SetReg "HKLM\SOFTWARE\SourceCodeControlProvider" ProviderRegKey "%REG_VALUENEW%"
		)
	@CALL :UnSetReg "HKLM\SOFTWARE\SourceCodeControlProvider" PreviousProviderRegKey
	@CALL :UnSetReg "HKLM\SOFTWARE\SourceCodeControlProvider\InstalledSCCProviders" "Functional Test ClearCase"
	@CALL :SetDwordReg "HKCU\SOFTWARE\Atria\ClearCase\CurrentVersion" CCVSOverRide 0
	@GOTO :EOF
    )
:RegisterCCTypeManager
	@if %ARG_ACTION% EQU ..uninstall.. (
		@CALL :DeleteRegKey "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1"
		@GOTO :EOF
	)
	
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" construct_version "..\..\bin\bdtm.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" create_branch "..\..\bin\bdtm.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" create_element "..\..\bin\bdtm.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" create_version "..\..\bin\bdtm.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" delete_branches_versions "..\..\bin\bdtm.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" compare "..\..\bin\cleardiff.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" xcompare "..\..\bin\xmldiffmrg.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" merge %FT_BIN_DIR%\rtmapmerge.exe
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" xmerge %FT_BIN_DIR%\rtmapmerge.exe
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" annotate "..\..\bin\bdtm.exe"
	@CALL :DefineReg "HKLM\SOFTWARE\Atria\ClearCase\CurrentVersion\TypeManagers\%1" get_cont_info "..\..\bin\bdtm.exe"
	
	@GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Set up Customization and Configuration directories
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CreateCustConfigDirs
	@ECHO === CreateCustConfigDirs
	@if %ARG_ACTION% EQU ..install.. (
		CALL :CreateCustConfigDirsInstall
		GOTO :EOF
	) 

	@if %ARG_ACTION% EQU ..uninstall.. (
		REM # *** Leave these setting in because directories NOT deleted because may contain 
		REM # *** user specific settings that we want to persist across installs.
		REM # CALL :UnSetRftReg "Rational FT Customization Directory"
		REM # CALL :UnSetRftReg "Rational FT Configuration Directory"
		@GOTO :EOF
	)
	if %ARG_ACTION% EQU ..query.. (
		CALL :QueryUserDir "Rational FT Customization Directory" "customization"
		CALL :QueryUserDir "Rational FT Configuration Directory" "configuration"
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

:CreateCustConfigDirsInstall
	CALL :CreateUserDir "Rational FT Customization Directory" "customization"
	@SET CUST_DIR=%cDir
	CALL :CreateUserDir "Rational FT Configuration Directory" "configuration"
	@GOTO :EOF

:CreateUserDir
	@SET cKEY=%1
	@SET cTYPE=%~2
	@echo === CreateUserDir: Attempting to compute %cTYPE% directory
	CALL :QueryUserDir %1 %2
	
	@if EXIST "%cDir%" (
		CALL :Debug  "Checking for customizations.rftcust......."
		CALL :CopyCustomFile %cTYPE% customizations.rftcust
		CALL :Debug  "Checking for CustomObjRecProp.rftop......."
		CALL :CopyCustomFile %cTYPE% CustomObjRecProp.rftop
		CALL :Debug  "Checking for CustomObjRecProp_MySAP.rftop......."
		CALL :CopyCustomFile %cTYPE% CustomObjRecProp_MySAP.rftop
		@GOTO :EOF
	  )

	REM # @SET cDir=C:\Documents and Settings\All Users\Application Data\IBM\RFT\%cTYPE%
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders" "Common AppData"
		@IF "%REG_VALUE%" EQU "" (
			@SET cdir=C:\Documents and Settings\All Users\Application Data\IBM\RFT\%cTYPE%
			@ECHO "Value for All Users\Application Data folder could not be retrieved from the registry.Hence falling back!!"
		) ELSE (
			@SET cDir=%REG_VALUE%\IBM\RFT\%cTYPE%
		)
	@ECHO Location of customization and configuration folder=%cDir%

	@if EXIST "%cDir%" (
		@echo "=== Default %cTYPE% directory exists %cDir%"
		CALL :Debug  "Checking for CustomObjRecProp.rftop......."
		CALL :CopyCustomFile %cTYPE% CustomObjRecProp.rftop
		CALL :Debug  "Checking for CustomObjRecProp_MySAP.rftop......."
		CALL :CopyCustomFile %cTYPE% CustomObjRecProp_MySAP.rftop			 
		
	) else (
		@echo "=== Create %cTYPE% directory "%cDir%"
		XCOPY /S /R /I /Y %FT_BIN_DIR%\%cTYPE% "%cDir%"
	)
	echo Y|cacls "%cDir%" /P Everyone:F /T
	CALL :SetRftReg %cKEY% "%cDir%"
	@GOTO :EOF

:QueryUserDir
	@SET cDir=
	@SET REG_QUERY=%RREG% query "hklm\SOFTWARE\Rational Software\Rational Test\8" /v %1
	@for /f "tokens=5*" %%i in ('%REG_QUERY%') do @SET cDir=%%j
	@if EXIST "%cDir%" (
		@echo "??QUERY?? Registry for %~2 is set and directory exists: %cDir%"
	) ELSE (
		@echo "??QUERY?? Registry for %~2 set but directory does not exist: %cDir%"
	)
	GOTO :EOF

REM # This function was written to support copying CustomObjRecProp.rftop AND  CustomObjRecProp_MySAP.rftop
REM # CustomObjRecProp.rftop and CustomObjRecProp_MySAP.rftop was introduced in RFT 7.0.0.2
REM # Update was failing to copy this file as customization folder pre-exsists
REM # This function forces the installer to look in ..\FunctionalTester\bin for CustomObjRecProp_MySAP.rftop and REM #  CustomObjRecProp.rftop
:CopyCustomFile
			@CALL :CheckFileExistance "%cDir%\..\customization\%2" QUIET
			@IF %ERR_CODE% EQU ..success.. (
				ECHO "%2 file is present ........"
				@GOTO :EOF
			)

			@CALL :CheckFileExistance %FT_BIN_DIR%\%cTYPE%\%2 QUIET 
			@IF %ERR_CODE% EQU ..success.. (
			CALL :Debug  "Copying %FT_BIN_DIR%\%cTYPE%\%2 to %cDir%"
			CALL :CopyFileToDir %FT_BIN_DIR%\%cTYPE%\%2 "%cDir%"
			)
		GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Set up ivory.plugin.properties
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:IvoryPluginProperties
	@ECHO =================== IvoryPluginProperties ===================
	if %ARG_ACTION% EQU ..install.. (
		%ARG_JRE%\bin\java.exe -jar "%IBM_RATIONAL_RFT_INSTALL_DIR%\rational_ft.jar" -updateplugins
		%ARG_JRE%\bin\java.exe -jar "%IBM_RATIONAL_RFT_INSTALL_DIR%\rational_ft.jar" -enable ENABLE_DEFAULTS
		@GOTO :EOF
	)
		
	if %ARG_ACTION% EQU ..uninstall.. (
		CALL :DeleteFile %FT_BIN_DIR%\ivory.plugin.properties
		@GOTO :EOF
	)

	if %ARG_ACTION% EQU ..query.. (
		type "%IBM_RATIONAL_RFT_INSTALL_DIR%\ivory.plugin.properties"
	)
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Set up Eclipse install
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:EclipseInstall
	@ECHO =================== EclipseInstall ===================
	if %ARG_ACTION% NEQ ..uninstall.. (
		REM # validate the eclipse directory
		@CALL :CheckFileExistance %ARG_ECLIPSE_EXE%
	)
	if %ARG_ACTION% NEQ ..uninstall.. (
		@IF %ERR_CODE% NEQ ..success..  (
			@GOTO :EOF
		)
	)		
	REM # rft uses the "Rational FT Java IDE" env var to find the eclipse ide for TestManager
	@CALL :DefineRftReg "Rational FT Java IDE" %ARG_ECLIPSE_EXE%
	REM # RFT uses rft.exe env var to find the eclipse ide for TestManager(used for backward compatiblity)
	if %ARG_ACTION% NEQ ..uninstall.. (
	@CALL :SetReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\rft.exe" "" %ARG_ECLIPSE_EXE%
	) ELSE (
	%RREG% delete "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\rft.exe" 
	)
	
	@SET ERR_CODE=..success..

	@GOTO :EOF


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Set RFT Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetRftReg
	@ECHO === SetRftReg %1=%2
	@CALL :SetReg "HKLM\SOFTWARE\Rational Software\Rational Test\8" %1 %2 
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Un-Set RFT Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UnSetRftReg
	@ECHO === UnSetRftReg (DELETE) %1
	@CALL :UnSetReg "HKLM\SOFTWARE\Rational Software\Rational Test\8" %1 
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Query RFT Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:QueryRftReg
	@CALL :QueryReg "HKLM\SOFTWARE\Rational Software\Rational Test\8" %1
	@GOTO :EOF

	
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Set Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetReg
	@ECHO === SetReg key:%1 value:%2 = %3
	%RREG% add %1 /v %2 /t REG_SZ /d %3
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Un-Set Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UnSetReg
	@ECHO === UnSetReg (DELETE) key:%1 value:%2
	%RREG% delete %1 /v %2
	@if errorlevel 1 (
		@rem You can ignore the above error.  It is due to the registry setting not being deleted.
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Set DWord Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetDwordReg
	@ECHO === SetDwordReg key:%1 value:%2 = %3
	@ECHO "%RREG%"
	%RREG% add %1 /v %2 /t REG_DWORD /d %3 
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Un-Set Registry Key
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:DeleteRegKey
	@ECHO === DeleteRegKey (DELETE) key:%1 
	%RREG% delete %1 
	@if errorlevel 1 (
		@rem You can ignore the above error.  It is due to the registry setting not being deleted.
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Query Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:QueryReg
	@REM # CALL :Debug === QueryReg %1 %2
	SET REG_VALUE=
	@for /f "delims== tokens=1-3" %%i in ('%RREG% query %1 /v %2 /p') do @SET REG_VALUE=%%j
	IF %1 =="HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" (
		@ECHO ??QUERY?? Environment %2="%REG_VALUE%"
	) ELSE (
		@ECHO ??QUERY?? Registry %1\%2="%REG_VALUE%"
	)
	@GOTO :EOF

:RemoveQuotes
@ECHO ----- RemoveQuotes %1, %2
SET %2=%~1%
GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Query Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:GetReg
	@REM # CALL :Debug === QueryReg %1 %2
	SET REG_VALUE=
	@for /f "delims== tokens=1-3" %%i in ('%RREG% query %1 /v %2 /p') do @SET REG_VALUE=%%j
	@GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                     Query Registry Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:GetPreviousProviderRegkey
	@REM # CALL :Debug === QueryReg %1 %2
	SET REG_VALUENEW=
	@for /f "delims== tokens=1-3" %%i in ('%RREG% query %1 /v %2 /p') do @SET REG_VALUENEW=%%j
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Set Environment Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetEnv
	@ECHO === SetEnv %1=%2
	@set value=%1
	@set data=%2
	@set ENV_KEY="HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" 
	%RREG% add %ENV_KEY% /v %value% /t REG_SZ /d %data%
	SET %1=%~2
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:
:FixFileNameSlashes
SET FILE_VALUE=%~f1
REM FOR /F "delims=)" %%v IN ("%~1") DO SET FILE_VALUE=%%~fv
@goto :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Un-Set Environment Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UnSetEnv
	@ECHO === UnSetEnv (remove environmentvar) %1
	@set value=%1
	@set ENV_KEY="HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" 
	%RREG% delete %ENV_KEY% /v %value%
    @if errorlevel 1 (
		CALL :Warning environment variable %1 not deleted.
		@GOTO :EOF
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Query Environment Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:QueryEnv
	REM # @CALL :Debug === QueryEnv %1
	@CALL :QueryReg "HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment"  %1
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 				Check For DotNet Frame Work 
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
REM # Note that CheckForDotNetFramework sets REGASM if it finds a .net framework.
:CheckForDotNetFramework
	@ECHO === CheckForDotNetFramework
	@SET REGASM=
	@SET NET_11_FOUND=..false..
	@SET NET_2_FOUND=..false..
	@SET NET_FRAMEWORK_FOUND=..false..
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\.NETFramework" "InstallRoot"
	@ECHO The InstallRoot for .NETFramework="%REG_VALUE%"
	@SET regasm1_1=%REG_VALUE%\v1.1.4322\regasm.exe
	@SET regasm2_0=%REG_VALUE%\v2.0.50727\regasm.exe

	@CALL :CheckFileExistance "%regasm1_1%" QUIET
	@IF %ERR_CODE% EQU ..success.. (
		@SET REGASM="%regasm1_1%"
		@ECHO "Found .Net Framework 1.1"
		@SET NET_11_FOUND=..true..
		@SET NET_FRAMEWORK_FOUND=..true..
	)

	@CALL :CheckFileExistance "%regasm2_0%" QUIET
	@IF %ERR_CODE% EQU ..success..  (
		@SET REGASM="%regasm2_0%"
		@ECHO "Found .Net Framework 2.0"
		@SET NET_2_FOUND=..true..
		@SET NET_FRAMEWORK_FOUND=..true..
	)

	@IF %NET_FRAMEWORK_FOUND% EQU ..true.. (
		@GOTO :EOF
	)
	
	@ECHO Could not find .Net Framework 2.0: "%regasm2_0%"
	@ECHO Could not find .Net Framework 1.1: "%regasm1_1%"
	@ECHO "No .Net Framework found"
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 				Update tNet Framework
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UpdateNetFramework
	@ECHO =================== UpdateNetFramework ===================
	REM # This depends on the CheckForDotNetFramework havin been called so
	REM # we know about the .net frameworks currently installed.
	REM # We then look into the bin dir to see if any rational_ft.exe
	REM # tools are installed - if they are, then .net was installed before.
	
	@CALL :CheckFileExistance %FT_BIN_DIR%\rational_ft.exe QUIET
	@IF  %ERR_CODE% NEQ ..error.. (
		@ECHO The NET FRAMEWORK 2.0 WAS ALREADY INSTALLED
		@GOTO :EOF
	)
	@CALL :CheckFileExistance %FT_BIN_DIR%\rational_ft11.exe QUIET
	@IF  %ERR_CODE% NEQ ..error.. (
		@ECHO The NET FRAMEWORK 1.1 WAS ALREADY INSTALLED
		@GOTO :EOF
	)

	setlocal
		SET ARG_ACTION=..install..
		CALL :GacUtilityRtxFtNet %FT_BIN_DIR% rtxftnet.dll policy.7.0.rtxftnet.dll


		CALL :Siebel
		CALL :SAP
	endlocal
	@GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                     Install into VS.Net 2003/2005/2010
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:VSNetInstall
	@ECHO =================== VSNetInstall ===================
	@IF %IDE_VSNET_DIR% EQU "..undefined.." (
		@ECHO *** No VSNET IDE Specified
		@GOTO :EOF
	)

	REM SET RFTTEMP=""
	REM @CALL :Concat %IDE_VSNET_DIR% "\devenv.exe" RFTTEMP
	@CALL :DefineRftReg "Rational FT VB.Net IDE" %IDE_VSNET_DIR%\devenv.exe

	CALL :CopyToVSNet %FT_VSNET_DIR%\RftVsNet.dll
	if %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)

	SET RFTTEMP=""
	CALL :Concat %FT_VSNET_DIR% "\RftVsNet.reg" RFTTEMP
	REM CALL :RegisterRegFile %FT_VSNET_DIR%\RftVsNet.reg
	CALL :RegisterRegFile %RFTTEMP%
	if %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)

	CALL :CopyToVSNet  %FT_BIN_DIR%\rtclearcaseif.dll
	if %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)
	@ECHO ====done with the copying of the clearcase dll	
	
	IF %ARG_VSNET71% NEQ "..undefined.." (
		SET RFTVS=Rftvs.dll
		SET RFTDPEDIT=RftDPEdit.dll
	)
	IF %ARG_VSNET8% NEQ "..undefined.." (
		SET RFTVS=Rftvs8.dll
		SET RFTDPEDIT=RftDPEdit8.dll
	)  
	IF %ARG_VSNET10% NEQ "..undefined.." (
		SET RFTVS=Rftvs10.dll
		SET RFTDPEDIT=RftDPEdit10.dll
	) 

	CALL :CallRegsrv %FT_VSNET_DIR%\bin\%RFTVS%
	if %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)

	CALL :CallRegsrv %FT_VSNET_DIR%\bin\%RFTDPEDIT%
	if %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)

	CALL :RunDevEnv

	CALL :MSDNHelp
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                     Get .Net IDE Location
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:GetNetIdeLocation
	@ECHO === GetNetIdeLocation %1
	CALL :QueryReg HKLM\SOFTWARE\Microsoft\VisualStudio\%1 InstallDir
	@IF "%REG_VALUE%" EQU "" (
		@ECHO ??QUERY?? VS.NET IDE %1 not installed
		GOTO :EOF
	) ELSE (
		@ECHO ??QUERY?? VS.NET IDE %1 found at: "%REG_VALUE%" 
	)
	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                     Query .Net IDE 
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:QueryNetIde
	@ECHO === QueryNetIde %1
	CALL :GetNetIdeLocation %1

	@IF %1 EQU 7.1 (
		SET ARG_VSNET71="%REG_VALUE%"
	)
	@IF %1 EQU 8 (
		SET ARG_VSNET8="%REG_VALUE%"
	)
	@IF %1 EQU 10.0 (
		SET ARG_VSNET10="%REG_VALUE%"
	)
	
	SET IDE_VSNET_DIR="%REG_VALUE%"
	CALL :VSNetInstall
	
	SET IDE_VSNET_DIR=
	SET ARG_VSNET71="..undefined.."
	SET ARG_VSNET8="..undefined.."
	SET ARG_VSNET10="..undefined.."	
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                     Install Config files for rational_ft.exe
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ConfigFT_EXE_FOR_NETFramework
	@ECHO === ConfigFT_EXE_FOR_NETFramework

	@if %ARG_ACTION% NEQ ..query.. (
		REM # Delete command line files from bin directory
		CALL :DeleteFile %FT_BIN_DIR%\rational_ft.exe.config
		CALL :DeleteFile %FT_BIN_DIR%\rational_ftw.exe.config
		CALL :DeleteFile %FT_BIN_DIR%\rational_ft.exe
		CALL :DeleteFile %FT_BIN_DIR%\rational_ftw.exe
		CALL :DeleteFile %FT_BIN_DIR%\rational_ft11.exe
		CALL :DeleteFile %FT_BIN_DIR%\rational_ftw11.exe
	)
	if %ARG_ACTION% EQU ..uninstall.. (
		@GOTO :EOF
	)

	if %ARG_ACTION% EQU ..install.. (
		@IF %NET_FRAMEWORK_FOUND% EQU ..true.. (
			CALL :CopyFile %FT_BIN_DIR%\NetCommandLine\rational_ft11.exe %FT_BIN_DIR%
			CALL :CopyFile %FT_BIN_DIR%\NetCommandLine\rational_ftw11.exe %FT_BIN_DIR%
			CALL :CopyFileToDir %FT_BIN_DIR%\NetCommandLine\rational_ft.exe.config %FT_BIN_DIR%
			CALL :CopyFileToDir %FT_BIN_DIR%\NetCommandLine\rational_ft.exe %FT_BIN_DIR%
			CALL :CopyFileToDir %FT_BIN_DIR%\NetCommandLine\rational_ftw.exe %FT_BIN_DIR%
			CALL :CopyFileToDir %FT_BIN_DIR%\NetCommandLine\rational_ftw.exe.config %FT_BIN_DIR%
		)
		@GOTO :EOF
	)
	
	@if %ARG_ACTION% EQU ..query.. (
		
		IF EXIST %FT_BIN_DIR%\rational_ft.exe (
			ECHO ??QUERY?? rational_ft.exe Found
		)
		IF EXIST %FT_BIN_DIR%\rational_ft.exe.config (
			ECHO ??QUERY?? rational_ft.exe.config Found
		)
		IF EXIST %FT_BIN_DIR%\rational_ftw.exe (
			ECHO ??QUERY?? rational_ftw.exe Found
		)
		IF EXIST %FT_BIN_DIR%\rational_ftw.exe.config (
			ECHO ??QUERY?? rational_ftw.exe.config Found
		)
		IF EXIST %FT_BIN_DIR%\rational_ft11.exe (
			ECHO ??QUERY?? rational_ft11.exe Found
		)
		IF EXIST %FT_BIN_DIR%\rational_ftw11.exe (
			ECHO ??QUERY?? rational_ftw11.exe Found
		)
		GOTO :EOF
	)
	
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                     Run GAC Utility with Policy file
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:GacUtilityRtxFtNet
	SET ERR_CODE=..success..
	@ECHO === GacUtilityRtxFtNet %1 %2 %3

	if %ARG_ACTION% EQU ..install.. (
		CALL :GacWithOptionalPolicyFile %1 %2 %3
		@GOTO :EOF
	) 
	if %ARG_ACTION% EQU ..uninstall.. (
		CALL :GacWithOptionalPolicyFile %1 %2 %3
		@GOTO :EOF
	)
	if %ARG_ACTION% EQU ..query.. (
		IF EXIST %windir%\assembly\gac\rtxftnet (
			ECHO ??QUERY?? rtxftnet is registered in the GAC
			DIR  %windir%\assembly\gac\rtxftnet 
		) ElSE (
			ECHO ??QUERY?? rtxftnet is NOT registered in the GAC
		)
		IF EXIST %windir%\assembly\gac\policy.7.0.rtxftnet (
			ECHO ??QUERY?? The PublisherPolicy file 7.0 is registered in the GAC
			DIR  %windir%\assembly\gac\policy.7.0.rtxftnet
		) ElSE (
			ECHO ??QUERY?? The PublisherPolicy file 7.0 is NOT registered in the GAC
		)
		IF EXIST %windir%\assembly\gac\policy.6.1.rtxftnet (
			ECHO ??QUERY?? The PublisherPolicy file 6.1 is registered in the GAC
			DIR  %windir%\assembly\gac\policy.6.1.rtxftnet
		) ElSE (
			ECHO ??QUERY?? The PublisherPolicy file 6.1 is NOT registered in the GAC
		)
		@ECHO QUERY GAC not yet supported
		GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF 


:GacWithOptionalPolicyFile
	SET RFTTEMP1=""
	SET RFTTEMP2=""
	@CALL :Concat %1 "\" RFTTEMP1
	@CALL :Concat %RFTTEMP1%  %2 RFTTEMP2
	CALL :LogInfo CheckFileExistance %RFTTEMP2%
	CALL :CheckFileExistance %RFTTEMP2%
	@IF  %ERR_CODE% EQU ..error.. (
		CALL :LogInfo File not found %RFTTEMP2%
		 GOTO :EOF
	)
	CALL :CheckFileExistance %1\%3 QUIET
	@IF %ERR_CODE% EQU ..success.. (
		CALL :GacWithPolicyFile %1 %2 %3
	) ELSE (
		CALL :GacWithoutPolicyFile %1 %2
	)
	GOTO:EOF
	

:GacWithPolicyFile
	SET ERR_CODE=..success..
	
	@if %ARG_ACTION% EQU ..install.. (
		%GACUtility% -a "%~1\%2" -p "%~1\%3" -o
	) ELSE (
		%GACUtility% -a "%~1\%2" -p "%~1\%3" -u
	)
	@IF %ERRORLEVEL% == 0 ( 
		@ECHO GACUtility %ARG_ACTION% succeeded on %2 with %3
	) else (
		@CALL :ERROR GACUtility %ARG_ACTION% failed on %2 with %3
	)
	GOTO :EOF

:GacWithoutPolicyFile
	SET ERR_CODE=..success..

	if %ARG_ACTION% EQU ..install.. (
		%GACUtility% -a "%~1\%2"  -o
	) ELSE (
		%GACUtility% -a "%~1\%2" -u
	)
	@IF %ERRORLEVEL% == 0 ( 
		@ECHO GACUtility %ARG_ACTION% succeeded on "%~1\%2"
	) else (
		REM # - this seems to signal failure when it succeeds???
		REM # CALL :Debug GACUtility %ARG_ACTION% failed on "%~1\%2"
	)
	GOTO :EOF

:UnGacWithoutPolicyFile
	SET ERR_CODE=..success..
	%GACUtility% -a "%~1\%2" -u
	@IF %ERRORLEVEL% == 0 ( 
		@ECHO GACUtility ..uninstall.. succeeded on "%~1\%2"
	) else (
		@CALL :ERROR GACUtility ..uninstall.. failed on "%~1\%2"
	)
	GOTO :EOF

:ParseRtxFtNetPolicyConfigForVersion
	PUSHD %FT_BIN_DIR%
	SET rtxFtNetVersion=
	FOR /F "delims=/= tokens=1-2" %%i IN (rtxftnetpolicy.config) DO (
		CALL :GetNewVersionString %%i %%j
	)
	CALL :Debug  RtxFtNet Policy file redirects to Version=%rtxFtNetVersion%
	POPD
	GOTO :EOF

:GetNewVersionString
	if "%1" == "newVersion" (
		set rtxFtNetVersion=%~2
	)
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			           Clean up rtClearCase
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CleanupRtClearCaseIfDLL
	@ECHO === CleanupRtClearCaseIfDLL
	PUSHD %FT_VSNET_DIR%
	%regasm% /unregister PrivateAssemblies\old\rtclearcaseif.dll"
	POPD
    @GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   MSDN Help
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:MSDNHelp
	@if %ARG_ACTION% EQU ..query.. (
		REM # QUERY MSDNHelp Not yet implemented
		@GOTO :EOF
	)
	@ECHO === MSDNHelp
	@if %ARG_ACTION% EQU ..install.. (
		CALL :MSDNHelpInstall
		@GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..uninstall.. (
		CALL :MSDNHelpUninstall
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

:MSDNHelpInstall
	
	IF %ARG_VSNET10% NEQ "..undefined.." (
		
	@ECHO Installing  VS2010 msdnhelp
	CALL :InstallVS2010Help
	@GOTO :EOF
	)
	SET FILTERQUERY="(\"DocSet\" =\"NETIBMFunctionalTesterSDK\" OR \"DocSet\" =\"NETIBMFunctionalTesterPROXYSDK\" OR \"DocSet\" = \"IBMRationalFunctionalTestUserGuide\" OR \"DocSet\" = \"Visual Basic\")"
	PUSHD "%FT_msdnhelp_DIR%"
	CALL :MSDNHelpUninstall QUIET
	IF %ARG_VSNET8% NEQ "..undefined.." (
		@ECHO === MSDNHelpInstall 2005
		
		CALL :Debug  Installing Help for VS2005

		CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.MSv2005" -collectionpath "." -collectionname "RftAPI.MSv2005"
		%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.MSv2005" -collectionpath "." -collectionname "RftAPI.MSv2005"

		CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.MSv2005" -collectionpath "." -collectionname "RftAPI.MSv2005" -mergename rft.msv2005
		%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.MSv2005" -collectionpath "." -collectionname "RftAPI.MSv2005" -mergename rft.msv2005

		CALL :Debug ADDHELP -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.MSv2005"
		%ADDHELP% -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.MSv2005"
				
		CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005" -collectionpath "." -collectionname "RftProxyAPI.MSv2005"
		%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005" -collectionpath "." -collectionname "RftProxyAPI.MSv2005"
		
		CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005" -collectionpath "." -collectionname "RftProxyAPI.MSv2005" -mergename rftProxy.msv2005
		%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005" -collectionpath "." -collectionname "RftProxyAPI.MSv2005" -mergename rftProxy.msv2005
		
		CALL :Debug ADDHELP -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005"
		%ADDHELP% -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005"

		CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.MSv2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.MSv2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		
		CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

		CALL :MSDNHelpInstallUserGuide2005

		Call :Debug ADDHELP -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.USER.2005"
		%ADDHELP% -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.USER.2005"

		CALL :MSDNHelpInstallProxySDKUserGuide2005

		Call :Debug ADDHELP -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005"
		%ADDHELP% -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005"
		
		
	
	)

	IF %ARG_VSNET71% NEQ "..undefined.." (
		@ECHO === MSDNHelpInstall 2003
		
		CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY" -collectionpath "." -collectionname "RftAPI"
		%ADDHELP% -addcollection "IBM.RATIONAL.IVORY" -collectionpath "." -collectionname "RftAPI"

		CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY" -collectionpath "." -collectionname "RftAPI" -mergename rft
		%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY" -collectionpath "." -collectionname "RftAPI" -mergename rft

		CALL :Debug ADDHELP -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY"
		%ADDHELP% -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY"
		
		CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.PROXYSDK" -collectionpath "." -collectionname "RftProxyAPI"
		%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.PROXYSDK" -collectionpath "." -collectionname "RftProxyAPI"
		
		CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK" -collectionpath "." -collectionname "RftProxyAPI" -mergename rftProxy
		%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK" -collectionpath "." -collectionname "RftProxyAPI" -mergename rftProxy
		
		CALL :Debug ADDHELP -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK"
		%ADDHELP% -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK"

		CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		%ADDHELP% -addfilter "IBM.RATIONAL.IVORY" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

		CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.PROXYSDK" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.PROXYSDK" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%


		CALL :MSDNHelpInstallUserGuide2003

		Call :Debug ADDHELP -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.USER.2003"
		%ADDHELP% -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.USER.2003"

		CALL :MSDNHelpInstallProxySDKUserGuide2003

		Call :Debug ADDHELP -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003"
		%ADDHELP% -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003"
		
	)
	POPD
	SET FILTERQUERY=
	@GOTO :EOF
	

:InstallVS2010Help
		@ECHO==== Install Vs2010 Help 
		
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1033"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is en-us ="%REG_VALUE%"
		CALL :installHelp2010 1033
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1028"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is zh-tw ="%REG_VALUE%"
		CALL :installHelp2010 1028
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1031"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is de-de ="%REG_VALUE%"
		CALL :installHelp2010 1031
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1034"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is es-es ="%REG_VALUE%"
		CALL :installHelp2010 1034
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1036"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is fr-fr ="%REG_VALUE%"
		CALL :installHelp2010 1036
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1040"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is It-It ="%REG_VALUE%"
		CALL :installHelp2010 1040
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1041"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is jp-jp"%REG_VALUE%"
		CALL :installHelp2010 1041
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1042"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is ko-kr ="%REG_VALUE%"
		CALL :installHelp2010 1042
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "2052"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is zh-cn ="%REG_VALUE%"
		CALL :installHelp2010 2052
		)
		@GOTO :EOF
:installHelp2010
		ECHO==== %1======
		
		@SET HLM=
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Help\v1.0" "AppRoot"
		@ECHO The InstallRoot for Help Library Manager is ="%REG_VALUE%"
		@SET HLM_VS2010_FOUND=%REG_VALUE%HelpLibManager.exe
		@ECHO helpexe is = %HLM_VS2010_FOUND%
		IF %1 EQU 1033 (
		@ECHO this is english
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale en-us /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\helpcontentsetup.msha
		)
		IF %1 EQU 1028 (
		@ECHO this is chinese taiwan
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale zh-tw /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\zh_TW\helpcontentsetup.msha
		)
		IF %1 EQU 1031 (
		@ECHO this is german
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale de-de /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\de\helpcontentsetup.msha
		)
		IF %1 EQU 1034 (
		@ECHO this is spanish
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale es-es /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\es\helpcontentsetup.msha
		)
		IF %1 EQU 1036 (
		@ECHO this is french
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale fr-fr /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\fr\helpcontentsetup.msha
		)
		IF %1 EQU 1040 (
		@ECHO this is italian
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale It-It /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\it\helpcontentsetup.msha
		)
		IF %1 EQU 1041 (
		@ECHO this is japnese
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale jp-jp /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\ja\helpcontentsetup.msha
		)
		IF %1 EQU 1042 (
		@ECHO this is korean
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale ko-kr /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\ko\helpcontentsetup.msha
		)
		IF %1 EQU 2052 (
		@ECHO this is chinese PRC
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale zh-cn /silent /sourceMedia %FT_VSNET_DIR%\MSDNHelp\VS2010\zh_CN\helpcontentsetup.msha
		)
		
		@GOTO :EOF

:MSDNHelpInstallUserGuide2003
	REM # Install the USER GUIDE
	PUSHD ..
	CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.USER.2003" -collectionpath "." -collectionname "ftnet_toc"
	%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.USER.2003" -collectionpath "." -collectionname "ftnet_toc"

	CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.USER.2003" -collectionpath "." -collectionname "ftnet_toc" -mergename rftUser
	%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.USER.2003" -collectionpath "." -collectionname "ftnet_toc" -mergename rftUser

	CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.USER.2003" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
	%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.USER.2003" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

	POPD

	CALL :Debug "Checking and Installing  Non English languages in MSDN Help -2003"
	CALL :MSDN_NONENGLISH_USERGUIDE_INSTALL 2003
	
	
	@GOTO :EOF

:MSDNHelpInstallUserGuide2005
	REM # Install the USER GUIDE
	PUSHD ..
	CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.USER.2005" -collectionpath "." -collectionname "ftnet_toc"
	%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.USER.2005" -collectionpath "." -collectionname "ftnet_toc"

	CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.USER.2005" -collectionpath "." -collectionname "ftnet_toc" -mergename rftUser
	%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.USER.2005" -collectionpath "." -collectionname "ftnet_toc" -mergename rftUser

	CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.USER.2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
	%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.USER.2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

	POPD
	
	CALL :Debug "Checking and Installing  Non English languages in MSDN Help -2005"
	CALL :MSDN_NONENGLISH_USERGUIDE_INSTALL 2005
	
	@GOTO :EOF

:MSDN_NONENGLISH_USERGUIDE_INSTALL
        SET VSHELP=..undefined..
	@IF "%1" == "2005" (
	SET VSHELP=8.0
	) ELSE (
	SET VSHELP=7.1
	)
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1028"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\zh_TW QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Traditional Chinese
			@CALL :MSDN_NONENGLISH zh_TW %1
		)
	)
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1031"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\de QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:German
			@CALL :MSDN_NONENGLISH de %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1034"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\es QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Spanish
			@CALL :MSDN_NONENGLISH es %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1036"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\fr QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:French
			@CALL :MSDN_NONENGLISH fr %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1040"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\it QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Italian
			@CALL :MSDN_NONENGLISH it %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1041"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\ja QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Japanese
			@CALL :MSDN_NONENGLISH ja %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1042"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\ko QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Korean
			@CALL :MSDN_NONENGLISH ko %1
 		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1046"
	@IF "%REG_VALUE%" NEQ "" (		
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\pt_BR QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Portuguese Brazilian
			@CALL :MSDN_NONENGLISH pt_BR %1
		)
	)
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "2052"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\zh_CN QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Simplified Chinese
			@CALL :MSDN_NONENGLISH zh_CN %1
		)
	)

	@GOTO :EOF


:MSDNHelpInstallProxySDKUserGuide2003
	REM # Install the Proxy SDK USER GUIDE
	PUSHD ..
	CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc"
	%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc"

	CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc" -mergename rftproxyuser
	%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc" -mergename rftproxyuser

	CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
	%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

	POPD

 	CALL :Debug "Checking and Installing  Non English languages in MSDN Help -2003"
 	CALL :MSDN_NONENGLISH_PROXYSDK_USERGUIDE_INSTALL 2003

	@GOTO :EOF


:MSDNHelpInstallProxySDKUserGuide2005
	REM # Install the Proxy SDK USER GUIDE
	PUSHD ..
	CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc"
	%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc"

	CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc" -mergename rftproxyuser
	%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc" -mergename rftproxyuser

	CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
	%ADDHELP% -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

	POPD

 	CALL :Debug "Checking and Installing  Non English languages in MSDN Help -2005"
 	CALL :MSDN_NONENGLISH_PROXYSDK_USERGUIDE_INSTALL 2005

	@GOTO :EOF


:MSDN_NONENGLISH_PROXYSDK_USERGUIDE_INSTALL
        SET VSHELP=..undefined..
	@IF "%1" == "2005" (
	SET VSHELP=8.0
	) ELSE (
	SET VSHELP=7.1
	)
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1028"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\zh_TW QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Traditional Chinese
			@CALL :MSDN_NONENGLISH_PROXYSDK zh_TW %1
		)
	)
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1031"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\de QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:German
			@CALL :MSDN_NONENGLISH_PROXYSDK de %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1034"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\es QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Spanish
			@CALL :MSDN_NONENGLISH_PROXYSDK es %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1036"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\fr QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:French
			@CALL :MSDN_NONENGLISH_PROXYSDK fr %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1040"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\it QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Italian
			@CALL :MSDN_NONENGLISH_PROXYSDK it %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1041"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\ja QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Japanese
			@CALL :MSDN_NONENGLISH_PROXYSDK ja %1
		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1042"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\ko QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Korean
			@CALL :MSDN_NONENGLISH_PROXYSDK ko %1
 		)
	)
      @CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "1046"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\pt_BR QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Portuguese Brazilian
			@CALL :MSDN_NONENGLISH_PROXYSDK pt_BR %1
		)
	)
	@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\%VSHELP%\Setup\VS\BuildNumber" "2052"
	@IF "%REG_VALUE%" NEQ "" (
		@CALL :CheckFileExistance %FT_VSNET_DIR%\MSDNHelp\zh_CN QUIET
		@IF %ERR_CODE% EQU ..success.. (
			@CALL :Debug  Installing Help for Visual Studio:Simplified Chinese
			@CALL :MSDN_NONENGLISH_PROXYSDK zh_CN %1
		)
	)

	@GOTO :EOF


:MSDNHelpUninstallUserGuide2003
	REM # Uninstall the USER GUIDE
	CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.USER.2003"
	%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.USER.2003"
	@GOTO :EOF

:MSDNHelpUninstallUserGuide2005
	REM # Uninstall the USER GUIDE
	CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.USER.2005"
	%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.USER.2005"
	@GOTO :EOF

:MSDNHelpUninstallProxySDKUserGuide2003
	REM # Uninstall the Proxy SDK USER GUIDE

	CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003"
	%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003"

	@GOTO :EOF

:MSDNHelpUninstallProxySDKUserGuide2005
	REM # Uninstall the Proxy SDK USER GUIDE

	CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005"
	%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005"

	@GOTO :EOF		

:MSDNHelpUninstall
	@IF "%1" NEQ "QUIET" (
		@ECHO === MSDNHelpUninstall
	)
	IF %ARG_VSNET10% NEQ "..undefined.." (
		
	@ECHO UNInstalling  VS2010 msdnhelp
	CALL :UNInstallVS2010Help
	@GOTO :EOF
	
	)
	PUSHD "%FT_msdnhelp_DIR%"
	IF %ARG_VSNET8% NEQ "..undefined.." (
		
		CALL :Debug  Uninstalling Help for VS2005

		CALL :Debug ADDHELP -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.MSv2005"
		%ADDHELP% -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.MSv2005"

		CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.MSv2005"
		%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.MSv2005"		
		
		CALL :Debug ADDHELP -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005"
		%ADDHELP% -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005"
		
		CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005"
		%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.MSv2005"
		
		CALL :Debug ADDHELP -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005"
		%ADDHELP% -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2005"

		CALL :MSDNHelpUninstallProxySDKUserGuide2005

		CALL :MSDNHelpUninstallUserGuide_NON_ENGLISH 2005 MSDN_PROXYSDK_USER_GUIDE
		
		CALL :Debug ADDHELP -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.USER.2005"
		%ADDHELP% -removeplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.USER.2005"

		CALL :MSDNHelpUninstallUserGuide2005
		
		CALL :MSDNHelpUninstallUserGuide_NON_ENGLISH 2005 MSDN_USER_GUIDE
		
	)
	IF %ARG_VSNET71% NEQ "..undefined.." (
		
		CALL :Debug  Uninstalling Help for VS2003

		CALL :Debug ADDHELP -removeplugin "MS.VSCC" -childnamespace "IBM.RATIONAL.IVORY"
		%ADDHELP% -removeplugin "MS.VSCC" -childnamespace "IBM.RATIONAL.IVORY"

		CALL :Debug ADDHELP -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY"
		%ADDHELP% -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY"

		CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY"
		%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY"
		
		CALL :Debug ADDHELP -removeplugin "MS.VSCC" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK"
		%ADDHELP% -removeplugin "MS.VSCC" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK"
		
		CALL :Debug ADDHELP -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK"
		%ADDHELP% -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK"
		
		CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK"
		%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK"

		CALL :Debug	ADDHELP -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003"
		%ADDHELP% -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.2003"

		CALL :MSDNHelpUninstallProxySDKUserGuide2003

		CALL :MSDNHelpUninstallUserGuide_NON_ENGLISH 2003 MSDN_PROXYSDK_USER_GUIDE

		CALL :Debug	ADDHELP -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.USER.2003"
		%ADDHELP% -removeplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.USER.2003"

		CALL :MSDNHelpUninstallUserGuide2003
		
		CALL :MSDNHelpUninstallUserGuide_NON_ENGLISH 2003 MSDN_USER_GUIDE
		
	)
	POPD
	
	@GOTO :EOF

:UNInstallVS2010Help
	@ECHO==== UNInstall Vs2010 Help 
		
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1033"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is en-us ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1033
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1028"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is zh-tw ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1028
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1031"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is de-de ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1031
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1034"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is es-es ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1034
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1036"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is fr-fr ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1036
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1040"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is It-It ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1040
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1041"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is jp-jp"%REG_VALUE%"
		CALL :UNinstallHelp2010 1041
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "1042"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is ko-kr ="%REG_VALUE%"
		CALL :UNinstallHelp2010 1042
		)
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\10.0\Setup\VS\BuildNumber" "2052"
		@IF "%REG_VALUE%" NEQ "" (
		@ECHO Locale is zh-cn ="%REG_VALUE%"
		CALL :UNinstallHelp2010 2052
		)
		@GOTO :EOF
:UNinstallHelp2010
		ECHO==== %1======
		
		@SET HLM=
		@CALL :QueryReg "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Help\v1.0" "AppRoot"
		@ECHO The InstallRoot for Help Library Manager is ="%REG_VALUE%"
		@SET HLM_VS2010_FOUND=%REG_VALUE%HelpLibManager.exe
		@ECHO helpexe is = %HLM_VS2010_FOUND%
		IF %1 EQU 1033 (
		@ECHO this is english
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale en-us /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1028 (
		@ECHO this is chinese taiwan
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale zh-tw /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1031 (
		@ECHO this is german
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale de-de /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1034 (
		@ECHO this is spanish
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale es-es/silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1036 (
		@ECHO this is french
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale fr-fr /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1040 (
		@ECHO this is italian
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale It-It /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1041 (
		@ECHO this is japnese
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale jp-jp /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 1042 (
		@ECHO this is korean
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale ko-kr /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		IF %1 EQU 2052 (
		@ECHO this is chinese PRC
		"%HLM_VS2010_FOUND%" /product VS /version 100 /locale zh-cn /silent /uninstall /vendor IBM /productName RFT /mediaBookList RFT
		)
		@GOTO :EOF

:MSDN_NONENGLISH

	PUSHD ..\%1
	        
		CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.USER.%2.%1" -collectionpath "." -collectionname "ftnet_toc"
		%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.USER.%2.%1" -collectionpath "." -collectionname "ftnet_toc"

		CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.USER.%2.%1" -collectionpath "." -collectionname "ftnet_toc" -mergename rftUser
		%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.USER.%2.%1" -collectionpath "." -collectionname "ftnet_toc" -mergename rftUser

		REM # CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.USER.%2.%1" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		REM # %ADDHELP% -addfilter "IBM.RATIONAL.IVORY.USER.%2.%1" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

		@IF "%2" == "2005" (
		%ADDHELP% -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.USER.%2.%1"
		) ELSE (
		%ADDHELP% -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.USER.%2.%1"
		)
	POPD
	
@GOTO :EOF


:MSDN_NONENGLISH_PROXYSDK

	PUSHD ..\%1
	        
		CALL :Debug ADDHELP -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc"
		%ADDHELP% -addcollection "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc"

		CALL :Debug ADDHELP -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc" -mergename rftproxyuser
		%ADDHELP% -addhelpfiles "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1" -collectionpath "." -collectionname "com.ibm.rational.test.ft.proxysdk.doc" -mergename rftproxyuser

		REM # CALL :Debug ADDHELP -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%
		REM # %ADDHELP% -addfilter "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1" -filtername "IBM Rational Functional Tester" -filterquery %FILTERQUERY%

		@IF "%2" == "2005" (
		%ADDHELP% -addplugin "MS.VSCC.v80" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1"
		) ELSE (
		%ADDHELP% -addplugin "MS.VSCC.2003" -childnamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1"
		)
	POPD
	
@GOTO :EOF


:MSDNHelpUninstallUserGuide_NON_ENGLISH

REM # We attempt to uninstall the USERGuide for all languages(Regardless of what was installed)
REM # Better approach would have been to save the languages installed and then uninstall them.
REM # But these approach would have involved either loading the registry or Writing and Reading a file
REM # To keep things simple deletion uninstallation of all NON_ENGLISH is attempted at uninstall.
	CALL :MSDNHelpUninstallUserGuide_NE zh_TW %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE de %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE es %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE fr %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE it %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE ja %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE ko %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE pt_BR %1 %2
	CALL :MSDNHelpUninstallUserGuide_NE zh_CN %1 %2
@GOTO :EOF	

:MSDNHelpUninstallUserGuide_NE 
	REM # Uninstall the USER GUIDE
	
	@IF "%3" == "MSDN_USER_GUIDE" (
	CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.USER.%2.%1"
	%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.USER.%2.%1"
	) ELSE (
	CALL :Debug ADDHELP -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1"
	%ADDHELP% -removenamespace "IBM.RATIONAL.IVORY.PROXYSDK.USER.%2.%1"
	)

	@GOTO :EOF
	


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   					SAP
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SAP
	@ECHO =================== SAP ===================
	@ECHO SAP install/uninstall has no required action
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   				 Siebel
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:Siebel
	@ECHO =================== Siebel ===================
	@if %ARG_ACTION% EQU ..query.. (
		@ECHO QUERY Siebel Not yet implemented
		GOTO :EOF
	)

	IF %REGASM% EQU ..undefined.. (
		CALL :Error INTERNAL PROBLEM: REGASM undefined when InstallSiebel called
		GOTO :EOF
	)
	if %ARG_ACTION% EQU ..install.. (
		IF "%CUST_DIR%" EQU "..undefined.." (
			CALL :Error INTERNAL PROBLEM: CUST Dir undefined when InstallSiebel called
			GOTO :EOF
		)
		REM # **** Clean up vestigal install artifacts, no longer install Siebel support in the cust folder
		@IF EXIST "%CUST_DIR%\rational_ft_siebel.jar" (
			@ECHO "Clean up vestigal Siebel install artifacts
			CALL :UnGacWithoutPolicyFile "%CUST_DIR%" Interop.cascomlib.dll
			CALL :UnGacWithoutPolicyFile "%CUST_DIR%" Interop.Shdocvw.dll
			CALL :UnGacWithoutPolicyFile "%CUST_DIR%" Interop.mshtml.dll
			CALL :UnGacWithoutPolicyFile "%CUST_DIR%" SiebelDomainProxies.dll
			CALL :UnGacWithoutPolicyFile "%CUST_DIR%" SiebelIEHelper.dll
			CALL :UnGacWithoutPolicyFile "%CUST_DIR%" SiebelNotificationListener.dll		

			CALL :DeleteFile "%CUST_DIR%\rational_ft_siebel.jar"
			CALL :DeleteFile "%CUST_DIR%\rational_ft_siebel.rftcust"
			CALL :DeleteFile "%CUST_DIR%\Interop.cascomlib.dll"
			CALL :DeleteFile "%CUST_DIR%\Interop.Shdocvw.dll"
			CALL :DeleteFile "%CUST_DIR%\Interop.mshtml.dll"
			CALL :DeleteFile "%CUST_DIR%\SiebelDomainProxies.dll"
			CALL :DeleteFile "%CUST_DIR%\SiebelIEHelper.dll"
			CALL :DeleteFile "%CUST_DIR%\SiebelNotificationListener.dll"
		)
	)
	CALL :GacWithoutPolicyFile %FT_BIN_DIR% Interop.cascomlib.dll
	if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :GacWithoutPolicyFile %FT_BIN_DIR% Interop.Shdocvw.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :GacWithoutPolicyFile %FT_BIN_DIR% Interop.mshtml.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :GacWithoutPolicyFile %FT_BIN_DIR% SiebelDomainProxies.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :GacWithoutPolicyFile %FT_BIN_DIR% SiebelIEHelper.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :GacWithoutPolicyFile %FT_BIN_DIR% SiebelNotificationListener.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :RegasmInBinDir SiebelDomainProxies.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :RegasmInBinDir SiebelIEHelper.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :RegasmInBinDir SiebelNotificationListener.dll
	@if not %ERR_CODE% EQU ..success.. @GOTO :EOF

	CALL :DefineRftReg "DefaultSiebelApplicationName" "Siebel Universal Agent"

	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Call Regsrv
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CallRegsrv
	@if %ARG_ACTION% EQU ..query.. (
		REM # QUERY regsrv not yet supported
		SET ERR_CODE=..success..
		@GOTO :EOF
	)
	@ECHO === CallRegsrv %1
	CALL :CheckFileExistance %1
	if %ERR_CODE% NEQ ..success.. ( 
		GOTO :EOF 
	)

	@if %ARG_ACTION% EQU ..install.. (
		CALL :CallRegsrvInstall %1
		@GOTO :EOF
	) 

	@if %ARG_ACTION% EQU ..uninstall.. (
		CALL :CallRegsrvUnInstall %1
		@GOTO :EOF
	)

	@CALL :ERROR INTERNAL - xx invalid action: %ARG_ACTION%
	@GOTO :EOF
	
:CallRegsrvInstall
	regsvr32.exe /s %1
	IF NOT %ERRORLEVEL% == 0 (
		@CALL :Error Regsvr32 failed on %1
	)
	GOTO :EOF

:CallRegsrvUnInstall
	regsvr32.exe /s /u %1
	IF NOT %ERRORLEVEL% == 0 (
		@CALL :Error Regsvr32 failed UNREGISTER on %1
	)
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Copy to VS Net
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CopyToVSNet
	@ECHO === CopyToVSNet %1

	if %ARG_ACTION% EQU ..install.. (
		CALL :CopyFileToDir %1 %IDE_VSNET_DIR%\PrivateAssemblies
		@GOTO :EOF
	) 
	if %ARG_ACTION% EQU ..uninstall.. (
		CALL :DeleteFile %IDE_VSNET_DIR%\PrivateAssemblies\%~nx1
		GOTO :EOF
	)
	@if %ARG_ACTION% EQU ..query.. (
		CALL :CopyToVSNetQuery %1
		GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

:CopyToVSNetQuery
	CALL :CheckFileExistance %IDE_VSNET_DIR%\PrivateAssemblies\%~nx1 QUIET
	@if %ERR_CODE% EQU ..success.. (
		@ECHO ??QUERY?? File Exists: %IDE_VSNET_DIR%\PrivateAssemblies\%~nx1
	) ELSE (
		@SET ERR_CODE=..success..
		@ECHO ??QUERY?? File Does Not Exist: %IDE_VSNET_DIR%\PrivateAssemblies\%~nx1
	)
	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Delete File
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:DeleteFile 
	@ECHO === DeleteFile %1
	SET ERR_CODE=..success..
	del /Q /F %1
	IF NOT %ERRORLEVEL% == 0 (
		@CALL :ERROR Delete File failed on %1
	)
	@GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Copy file to Dir
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CopyFileToDir
	CALL :CheckFileExistance %1
	@if  %ERR_CODE% NEQ ..success.. @GOTO :EOF

	CALL :Debug copy /Y /V %1 "%~2\."
	copy /Y /V %1 "%~2\."
	IF NOT %ERRORLEVEL% == 0 (
		@CALL :Error  copy failed: %1 TO DIRECTORY "%~2\."
	)
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Copy file
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CopyFile
	CALL :CheckFileExistance %1
	@if  %ERR_CODE% NEQ ..success.. @GOTO :EOF

	CALL :Debug copy /Y /V %1 "%~2\."
	copy /Y /V %1 %2
	IF NOT %ERRORLEVEL% == 0 (
		@CALL :Error  copy failed: %1 TO FILE %2
	)
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Register REG file
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:RegisterRegFile
	@if %ARG_ACTION% EQU ..query.. (
		REM # QUERY register reg file not yet supported
		SET ERR_CODE=..success..
		@GOTO :EOF
	)

	@ECHO === RegisterRegFile %1
	SET regFile=%1

	if %ARG_ACTION% EQU ..install.. (
		regedit /s %regFile%
		@GOTO :EOF
	) 
	if %ARG_ACTION% EQU ..uninstall.. (
		REM # - can't unregister this
		@GOTO :EOF
	)
	@CALL :ERROR INTERNAL - invalid action: %ARG_ACTION%
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Run DevEnv
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:RunDevEnv
	@if %ARG_ACTION% EQU ..query.. (
		@GOTO :EOF
	)
	@ECHO === RunDevEnv
	REM # Attempting to Suppresing the warning that pops up with Windows Vista using VS2005
	
	ver | find "Microsoft Windows [Version 6" > nul
	if %ERRORLEVEL% == 0 GOTO VistaSupport
	
	%IDE_VSNET_DIR%\devenv.exe /setup
	@if errorlevel 1 (
		@CALL :Error returned running %IDE_VSNET_DIR%\devenv.exe
	) else (
		@ECHO SUCCESS running devenv /setup for VS .Net %product%!
	)
	@GOTO :EOF

	:VistaSupport
	@ECHO  Windows Vista :The Compatibility issue warning for VS2005 will be suppressed"
	reg add "HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\AppCompatFlags" /v {5f66dbae-cad3-468a-83d0-77ace8abc1f6} /t REG_DWORD /d 4 /f
	%IDE_VSNET_DIR%\devenv.exe /setup
	@if errorlevel 1 (
		@CALL :Error returned running %IDE_VSNET_DIR%\devenv.exe
	) else (
		@ECHO SUCCESS running devenv /setup for VS .Net %product%!
	)
	@CALL :UnSetReg "HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\AppCompatFlags" {5f66dbae-cad3-468a-83d0-77ace8abc1f6}
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 			Regasm in FunctionalTester\bin Directory
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:RegasmInBinDir
	if %ARG_ACTION% EQU ..query.. (
		@GOTO :EOF
	) 
	@ECHO === RegasmInBinDir %1
	@SET regThis=%FT_BIN_DIR%\%~1

	CALL :CheckFileExistance %regThis% QUIET
	@IF NOT %ERR_CODE% EQU ..success.. (
		@CALL :ERROR Can't run regasm on non existent file:  %regThis%
		@GOTO :EOF
	)

	PUSHD %FT_BIN_DIR%
	if %ARG_ACTION% EQU ..install.. (
		%REGASM% %1 
	) ELSE (
		%REGASM% %1 /unregister
	)
	@IF	%ERRORLEVEL% == 1 (
		@CALL :ERROR regasm failed on %1
	)
	POPD
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Associate File Types
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:AssociateFileTypes
@ECHO # --------------------- AssociateFileTypes ------------------------	
	SET RFTTEMP=""
	CALL :Concat %FT_BIN_DIR% "\rftLog.bat" RFTTEMP
	@if %ARG_ACTION% EQU ..install.. (
		FTYPE RationalFunctionalTestLog=%RFTTEMP% "%%1"
		ASSOC .RFTLOG=RationalFunctionalTestLog
	) 

	if %ARG_ACTION% EQU ..uninstall.. (
		ASSOC .RFTLOG
	)

	@GOTO :EOF


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                                         Validate ARG_JRE
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ValidateArgJre
	@CALL :CheckFileExistance %ARG_JRE%
	IF %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)
	@CALL :CheckFileExistance %ARG_JRE%\bin\java.exe
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                                         Validate ARG_ECLIPSE
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ValidateArgEclipse
	@CALL :CheckFileExistance %ARG_ECLIPSE%
	IF %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)
	@CALL :CheckFileExistance %ARG_ECLIPSE_EXE%
	IF %ERR_CODE% NEQ ..success.. (
		@GOTO :EOF
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                                         Check For a file existance
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CheckFileExistance
	IF "%2" NEQ "QUIET" (
		@ECHO === CheckFileExistance %1
	)
	SET ERR_CODE=..success..
	IF NOT EXIST %1 (
		IF "%2" == "QUIET" (
			SET ERR_CODE=..error..
			GOTO :EOF
		)
		@CALL :Error  Could not find %1
	)
	GOTO :EOF 

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Debug  Message
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:Debug
	@if %DEBUG_OUTPUT% EQU ..true.. (
		@ECHO DEBUG--- %*
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Error Message
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:Error
	set ERR_CODE=..error..
	@ECHO ERROR - %*
	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Error Message
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:ErrorNoStop
	set ERR_CODE=..success..
	@ECHO ERROR - %*
	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Warning
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:Warning
	set ERR_CODE=..success..
	@ECHO WARNING - %*
	GOTO :EOF
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Log
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:LogInfo
	set ERR_CODE=..success..
	@ECHO LogInfo - %*
	GOTO :EOF

:LAST
	@echo "--------------------------------------------------------------------- "

