#!/usr/bin/perl

# IBM Confidential 
#	
#   (c) Copyright IBM Corp. 2000, 2006 All Rights Reserved.
#
#   The source code for this program is not published or otherwise 
#   divested of its trade secrets, irrespective of what has been 
#   deposited with the U.S. Copyright Office.
#
#   Usage :
#   installinternal.sh -INSTALL /root/caspian/ -JRE /root/caspian/eclipse/jre 
#		       {-ECLIPSE /root/caspian/eclipse , -ECLIPSE_LAUNCHER /root/caspian/eclipse/eclipse.bin}
#
#   installinternal.sh -UNINSTALL /root/caspian/

use File::Basename;

map (s/^-//,@ARGV);
%hash=@ARGV;

$JRE=$hash{JRE};
$ECLIPSE_BIN=$hash{ECLIPSE_LAUNCHER};
$ECLIPSE=$hash{ECLIPSE};
$UNINSTALL=$hash{UNINSTALL};
$JAVA_SCRIPT=1 if exists $hash{RFT_JAVA};

if ($ECLIPSE_BIN) {
print "eclipse_launcher defined";
$ECLIPSE_DIR=dirname($ECLIPSE_BIN);
print "setting ECLIPSE_DIR=$ECLIPSE_DIR\n";
} else {
$ECLIPSE_DIR="$ECLIPSE";
$ECLIPSE_BIN="$ECLIPSE_DIR/eclipse";
print "eclipse launcher not defined, eclipse defined instead\n";
print "setting ECLIPSE_DIR=$ECLIPSE_DIR\n";
print "setting ECLIPSE_BIN=$ECLIPSE_BIN\n";
}

if (!$ECLIPSE_DIR) {
        print "Error!! Both -ECLIPSE_LAUNCHER and -ECLIPSE are not defined\n";
}

$ENV_DIR="/etc/profile.d";
$CUSTCONFROOTDIR="/etc/opt/IBM/Rational/RFT";

print ("Script called with :\n@ARGV\n");

#
# Don't remove customization/configuration directories during uninstallation.
#
sub delFile {
    $fname=shift;

    if (-e "$fname") {
        print ("Removing the file $fname\n");
        unlink("$fname");
    } else {
        print ("The file $fname doesn't exist\n");
    }
}

sub CleanOnUninstall {
     $curdir = $ENV{'PWD'};

     if (!$UNINSTALL) {
         print ("Functional Tester install location is not passed\n");
         exit 1;
     }

     if (!$JRE) {
         print ("JRE is not passed as an argument\n");
         print ("Disabling Functional Tester enabled environments may not work\n"); 
     }

     $source_env="source $UNINSTALL/FunctionalTester/bin/rtsetup";
     $unenable_jre="$UNINSTALL/FunctionalTester/installscripts/unenable_jre.bin";
     $disable_all="$JRE/bin/java -jar $UNINSTALL/FunctionalTester/bin/rational_ft.jar -disableall";

     print ("Removing the RFT scripts from $installdir ...\n");
     if (exists $hash{RFT_JAVA}) {
         print ("Uninstall Java scripting\n");

         if (-e "$UNINSTALL/ft_agent_start") {
             print ("Deleting only $UNINSTALL/ft_starter\n");
             delFile("$UNINSTALL/ft_starter");
         } else {

             print ("Disabling the RFT enablement...\n");
             chdir $JRE;
             system("$source_env; $unenable_jre; $disable_all");
             chdir $curdir;

             print ("Deleting all the files (except ft_agent_start)\n");
             delFile("$UNINSTALL/ft_starter");
             delFile("$UNINSTALL/ft_cmdline");
             delFile("$UNINSTALL/FunctionalTester/bin/rtsetup");
             delFile("$UNINSTALL/FunctionalTester/bin/ivory.plugin.properties");
             delFile("$JRE/lib/accessibility.properties");
             delFile("$ENV_DIR/rft.sh");
             delFile("$ENV_DIR/rft.csh");
	delFile("$UNINSTALL/FunctionalTester/RQMAdapter/startadapter");
	delFile("$UNINSTALL/FunctionalTester/RQMAdapter/configureadapter");
	delFile("$UNINSTALL/FunctionalTester/bin/rftLog");
         }
     } else {
         print ("Uninstall Agent\n");

         if (-e "$UNINSTALL/ft_starter") {
             print ("Deleting only $UNINSTALL/ft_agent_start\n");
             delFile("$UNINSTALL/ft_agent_start");
         } else {
             print ("Disabling the RFT enablement...\n");
             chdir $JRE;
             system("$source_env; $unenable_jre; $disable_all");
             chdir $curdir;

             print ("Deleting all the files (except for ft_starter)\n");
             delFile("$UNINSTALL/ft_agent_start");
             delFile("$UNINSTALL/ft_cmdline");
             delFile("$UNINSTALL/FunctionalTester/bin/rtsetup");
             delFile("$UNINSTALL/FunctionalTester/bin/ivory.plugin.properties");
             delFile("$JRE/lib/accessibility.properties");
             delFile("$ENV_DIR/rft.sh");
             delFile("$ENV_DIR/rft.csh");
	delFile("$UNINSTALL/FunctionalTester/RQMAdapter/startadapter");
	delFile("$UNINSTALL/FunctionalTester/RQMAdapter/configureadapter");
	delFile("$UNINSTALL/FunctionalTester/bin/rftLog");
         }
     }

     exit 0;
}

&CleanOnUninstall() if exists $hash{UNINSTALL};

#
# Rest is the installation part
#

$INSTALL=$hash{INSTALL};
$INSTALL_FT_BIN="$INSTALL/FunctionalTester/bin";
$RFT_ROOT="\$IBM_RATIONAL_RFT_INSTALL_DIR/../..";

#
# Messages
#

$copyright=<<"END";
\# IBM Confidential
\#
\#   (c) Copyright IBM Corp. 2000, 2006 All Rights Reserved.
\#
\#   The source code for this program is not published or otherwise
\#   divested of its trade secrets, irrespective of what has been
\#   deposited with the U.S. Copyright Office.
END

$message=<<"END";

print_env_message() {
        echo "#################################################################"
        echo "IBM_RATIONAL_RFT_INSTALL_DIR is not set in this shell."
        echo "You may need to re-login (or reboot) after RFT installation to"
        echo "have the RFT environement variables set in your environment."
        echo "Sourcing /etc/profile.d/rft.sh to set the environment for now..."
        echo "#################################################################"
}

print_install_error() {
        echo "#######################################"
        echo "/etc/profile.d/rft.[c]sh is not found"
        echo "RFT installation was not complete!"
        echo "#######################################"
}
END

#
# List environment variables.
#

$setenv_sh=<<"END";
export IBM_RATIONAL_RFT_INSTALL_DIR=$INSTALL_FT_BIN
export IBM_RATIONAL_RFT_ECLIPSE_DIR=$ECLIPSE_DIR
export IBM_RATIONAL_RFT_ECLIPSE_BIN=$ECLIPSE_BIN
export RATIONAL_FT_CONFIGURATION_DIRECTORY=$CUSTCONFROOTDIR/configuration
export RATIONAL_FT_CUSTOMIZATION_DIRECTORY=$CUSTCONFROOTDIR/customization
export RATIONAL_FT_JRE="$JRE"
END

$setenv_csh=<<"END";
setenv IBM_RATIONAL_RFT_INSTALL_DIR $INSTALL_FT_BIN
setenv IBM_RATIONAL_RFT_ECLIPSE_DIR $ECLIPSE_DIR
setenv IBM_RATIONAL_RFT_ECLIPSE_BIN $ECLIPSE_BIN
setenv RATIONAL_FT_CONFIGURATION_DIRECTORY $CUSTCONFROOTDIR/configuration
setenv RATIONAL_FT_CUSTOMIZATION_DIRECTORY $CUSTCONFROOTDIR/customization
setenv RATIONAL_FT_JRE "$JRE"
END


#
# Checking environment variable setting code inside the launcher scripts
#

$rft_env=<<"END";

if [ x"\$IBM_RATIONAL_RFT_INSTALL_DIR" = x ]; then
    if [ -f $ENV_DIR/rft.sh ]
    then
	print_env_message
    	. $ENV_DIR/rft.sh

	if [ \$? -ne 0 ]
	then
	    echo "Problems setting up RFT environment"
	    exit 1
	fi
    else
	print_install_error
	exit 1
    fi
fi

END


#
# Launcher script code
#

$ft_starter=<<"END";
#!/bin/sh

$copyright

\#
\# Launcher script to launch RFT
\#

$message

$rft_env

\${IBM_RATIONAL_RFT_ECLIPSE_BIN} -product com.ibm.rational.rft.product.ide
END


$ft_cmdline=<<"END";
#!/bin/sh

$copyright

\# Launcher script to execute command line interface of RFT
\# This script takes the arguments to command line interface.
\# For e.g, "ft_cmdline -enable"

$message

$rft_env

"\$RATIONAL_FT_JRE/bin/java" -jar \$IBM_RATIONAL_RFT_INSTALL_DIR/rational_ft.jar \$@
END


$rtsetup=<<"END";
#!/bin/sh

$copyright

\# This script can be used to source the RFT environment 
\# variables in the current shell.

$setenv_sh

\#If starting your application, uncomment the line below
\#export LD_PRELOAD=$INSTALL_FT_BIN/libftevent.so
END


$ft_agent_start=<<"END";
#!/bin/sh

$copyright

\#
\# This launcher script sets the required RFT environment
\# variables and starts RAServer.

$message

$rft_env

$INSTALL/../SDP70Shared/AgentController/bin/RAStart.sh

if [ \$? -ne 0 ]
then
    echo "RAServer returned error \$?"
    exit 1
fi
END

$ft_configadapter=<<"END";
#!/bin/sh

$copyright

\# Launcher script to configure the adapter to talk to 
\# Rational Quality Manager. 
\# For e.g, "configureadapter"

$message

$rft_env

"\$RATIONAL_FT_JRE/bin/java" -cp \$IBM_RATIONAL_RFT_INSTALL_DIR/rational_ft.jar com.rational.test.ft.RQMAdapterConfigure \$@
END

$ft_startadapter=<<"END";
#!/bin/sh

$copyright

\# Launcher script to start the adapter to talk to 
\# Rational Quality Manager. 
\# For e.g, "startadapter"

$message

$rft_env

"\$RATIONAL_FT_JRE/bin/java" -cp \$IBM_RATIONAL_RFT_INSTALL_DIR/rational_ft.jar com.rational.test.ft.RQMAdapterLauncher \$@
END

$ft_rftlog=<<"END";
#!/bin/sh

$copyright

\# Launcher script to open the Detailed RQM Log
\# For e.g, "rftlog <<zip log file>>"

$message

$rft_env

"\$RATIONAL_FT_JRE/bin/java" -cp \$IBM_RATIONAL_RFT_INSTALL_DIR/rational_ft.jar com.rational.test.ft.FtLog -zlog \$@
END


#
# Create rft.[c]sh files under /etc/profile.d
#
sub CreateEnv {
        my $file=shift;
        my $content=shift;

	print "Creating $ENV_DIR/$file\n";

        open SCRIPT,">$ENV_DIR/$file";
        print SCRIPT $content;
        close SCRIPT;
        chmod 0755,"$ENV_DIR/$file";
}

#
# To create launcher scripts
#
sub CreateLauncher {
	my $file=shift;
	my $content=shift;

	print "Creating $INSTALL/$file\n";

	open SCRIPT,">$INSTALL/$file";
	print SCRIPT $content;
	close SCRIPT;
	chmod 0755,"$INSTALL/$file";
}

#
# Create customization and configuration directories.
# These directories should be outside installation directory.
#
sub CreateCustConfDir {
    my $cname=shift;
    my $fname=shift;
    my $dirname=join('/', $CUSTCONFROOTDIR, $cname);
    my $c_fname=join('/', $dirname, $fname);

    if (!-e $dirname) {
        print "Creating $dirname\n";
        system("mkdir -p \"$dirname\"");
        if ($? != 0) {
            print "Creating $dirname failed with $?\n";
        }
    }

    if (!-e $c_fname) {
        print "Copying $INSTALL_FT_BIN/$cname/$fname to $dirname\n";
        system("cp $INSTALL_FT_BIN/$cname/$fname $dirname");
    }
    `chmod a+w "$dirname"`;
    if ($? != 0) {
         print "Copy failed with $? \n";
    }
}

# Now is the "action" part


&CreateEnv("rft.sh",$setenv_sh); 
&CreateEnv("rft.csh",$setenv_csh);
&CreateCustConfDir("customization", "customizations.rftcust");
&CreateCustConfDir("customization", "CustomObjRecProp.rftop");
&CreateCustConfDir("customization", "CustomObjRecProp_MySAP.rftop");
&CreateCustConfDir("configuration", "configurations.rftcfg");
&CreateLauncher("ft_cmdline",$ft_cmdline);
&CreateLauncher("FunctionalTester/bin/rtsetup",$rtsetup);
&CreateLauncher("ft_starter",$ft_starter) if exists $hash{RFT_JAVA};
&CreateLauncher("FunctionalTester/RQMAdapter/startadapter",$ft_startadapter);
&CreateLauncher("FunctionalTester/RQMAdapter/configureadapter",$ft_configadapter);
&CreateLauncher("FunctionalTester/bin/rftLog",$ft_rftlog);
### RATL00147371
#&CreateLauncher("ft_agent_start",$ft_agent_start) unless exists $hash{RFT_JAVA};

#
# Generate the ivory.plugin.properties, if it
# doessn't exist in FT bin directory
#
unless (-f "$INSTALL_FT_BIN/ivory.plugin.properties"){
        $ENV{RATIONAL_FT_CUSTOMIZATION_DIRECTORY}="$CUSTCONFROOTDIR/customization";
        $ENV{RATIONAL_FT_CONFIGURATION_DIRECTORY}="$CUSTCONFROOTDIR/configuration";
        $ENV{IBM_RATIONAL_RFT_INSTALL_DIR}="$INSTALL_FT_BIN";
        $ENV{IBM_RATIONAL_RFT_ECLIPSE_DIR}="$ECLIPSE_DIR";
        $ENV{RATIONAL_FT_JRE}="$JRE";

        print "Generate $INSTALL_FT_BIN/ivory.plugin.properties";
        system("\$RATIONAL_FT_JRE/bin/java -jar \$IBM_RATIONAL_RFT_INSTALL_DIR/rational_ft.jar -updateplugins");
        print "Enabling default JRE";
        system("\$RATIONAL_FT_JRE/bin/java -jar \$IBM_RATIONAL_RFT_INSTALL_DIR/rational_ft.jar -enable ENABLE_DEFAULTS");
}

